@@ -59,18 +59,18 @@
 #ifndef LUT_H_
 #define LUT_H_
 
-#include <cstring>
-#include <cstdint>
 #include <cassert>
+#include <cstdint>
+#include <cstring>
 
 #ifndef NDEBUG
-#include <glibmm.h>
 #include <fstream>
+#include <glibmm.h>
 #endif
 
+#include "noncopyable.h"
 #include "opthelper.h"
 #include "rt_math.h"
-#include "noncopyable.h"
 
 // Bit representations of flags
 enum {
@@ -79,8 +79,7 @@ enum {
     LUT_CLIP_ABOVE  // LUT clips input values at upper bound
 };
 
-template<typename T>
-class LUT;
+template <typename T> class LUT;
 
 using LUTf = LUT<float>;
 using LUTi = LUT<int32_t>;
@@ -88,17 +87,16 @@ using LUTu = LUT<uint32_t>;
 using LUTd = LUT<double>;
 using LUTuc = LUT<uint8_t>;
 
-template<typename T>
-class LUT
-{
+template <typename T> class LUT {
 protected:
     // list of variables ordered to improve cache speed
     int maxs;
     float maxsf;
-    T * data;
+    T *data;
     unsigned int clip;
     unsigned int size;
-    unsigned int upperBound;  // always equals size-1, parameter created for performance reason
+    unsigned int upperBound; // always equals size-1, parameter created for
+                             // performance reason
 private:
     unsigned int owner;
 #ifdef __SSE2__
@@ -107,11 +105,13 @@ private:
     alignas(16) vint sizeiv;
 #endif
 public:
-    /// convenience flag! If one doesn't want to delete the buffer but want to flag it to be recomputed...
-    /// The user have to handle it itself, even if some method can (re)initialize it
+    /// convenience flag! If one doesn't want to delete the buffer but want to
+    /// flag it to be recomputed... The user have to handle it itself, even if
+    /// some method can (re)initialize it
     bool dirty;
 
-    LUT(int s, int flags = LUT_CLIP_BELOW | LUT_CLIP_ABOVE, bool initZero = false)
+    LUT(int s, int flags = LUT_CLIP_BELOW | LUT_CLIP_ABOVE,
+        bool initZero = false)
     {
 #ifndef NDEBUG
 
@@ -119,13 +119,13 @@ public:
             printf("s<=0!\n");
         }
 
-        assert (s > 0);
+        assert(s > 0);
 #endif
         dirty = true;
         clip = flags;
-        // Add a few extra elements so [](vfloat) won't access out-of-bounds memory.
-        // The routine would still produce the right answer, but might cause issues
-        // with address/heap checking programs.
+        // Add a few extra elements so [](vfloat) won't access out-of-bounds
+        // memory. The routine would still produce the right answer, but might
+        // cause issues with address/heap checking programs.
         data = new T[s + 3];
         owner = 1;
         size = s;
@@ -133,15 +133,16 @@ public:
         maxs = size - 2;
         maxsf = (float)maxs;
 #ifdef __SSE2__
-        maxsv =  F2V( maxs );
-        sizeiv =  _mm_set1_epi32( (int)(size - 1) );
-        sizev = F2V( size - 1 );
+        maxsv = F2V(maxs);
+        sizeiv = _mm_set1_epi32((int)(size - 1));
+        sizev = F2V(size - 1);
 #endif
         if (initZero) {
             clear();
         }
     }
-    void operator ()(int s, int flags = LUT_CLIP_BELOW | LUT_CLIP_ABOVE, bool initZero = false)
+    void operator()(int s, int flags = LUT_CLIP_BELOW | LUT_CLIP_ABOVE,
+                    bool initZero = false)
     {
 #ifndef NDEBUG
 
@@ -149,7 +150,7 @@ public:
             printf("s<=0!\n");
         }
 
-        assert (s > 0);
+        assert(s > 0);
 #endif
 
         if (owner && data) {
@@ -166,14 +167,13 @@ public:
         maxs = size - 2;
         maxsf = (float)maxs;
 #ifdef __SSE2__
-        maxsv =  F2V( maxs );
-        sizeiv =  _mm_set1_epi32( (int)(size - 1) );
-        sizev = F2V( size - 1 );
+        maxsv = F2V(maxs);
+        sizeiv = _mm_set1_epi32((int)(size - 1));
+        sizev = F2V(size - 1);
 #endif
         if (initZero) {
             clear();
         }
-
     }
 
     LUT()
@@ -192,45 +192,35 @@ public:
         if (owner) {
             delete[] data;
 #ifndef NDEBUG
-            data = (T*)0xBAADF00D;
+            data = (T *)0xBAADF00D;
 #endif
         }
     }
 
-    explicit LUT(const LUT&) = delete;
+    explicit LUT(const LUT &) = delete;
 
-    void setClip(int flags)
-    {
-        clip = flags;
-    }
+    void setClip(int flags) { clip = flags; }
 
-    int getClip() const {
-        return clip;
-    }
+    int getClip() const { return clip; }
 
-    /** @brief Get the number of element in the LUT (i.e. dimension of the array)
-     *  For a LUT(500), it will return 500
+    /** @brief Get the number of element in the LUT (i.e. dimension of the
+     * array) For a LUT(500), it will return 500
      *  @return number of element in the array
      */
-    unsigned int getSize() const
-    {
-        return size;
-    }
+    unsigned int getSize() const { return size; }
 
     /** @brief Get the highest value possible (i.e. dimension of the array)
-     *  For a LUT(500), it will return 499, because 500 elements, starting from 0, goes up to 499
+     *  For a LUT(500), it will return 499, because 500 elements, starting from
+     * 0, goes up to 499
      *  @return number of element in the array
      */
-    unsigned int getUpperBound() const
-    {
-        return size > 0 ? upperBound : 0;
-    }
+    unsigned int getUpperBound() const { return size > 0 ? upperBound : 0; }
 
-    LUT<T> & operator=(const LUT<T>& rhs)
+    LUT<T> &operator=(const LUT<T> &rhs)
     {
         if (this != &rhs) {
             if (rhs.size > this->size) {
-                delete [] this->data;
+                delete[] this->data;
                 this->data = nullptr;
             }
 
@@ -247,25 +237,27 @@ public:
             this->maxs = this->size - 2;
             this->maxsf = (float)this->maxs;
 #ifdef __SSE2__
-            this->maxsv =  F2V( this->size - 2);
-            this->sizeiv =  _mm_set1_epi32( (int)(this->size - 1) );
-            this->sizev = F2V( this->size - 1 );
+            this->maxsv = F2V(this->size - 2);
+            this->sizeiv = _mm_set1_epi32((int)(this->size - 1));
+            this->sizev = F2V(this->size - 1);
 #endif
         }
 
         return *this;
     }
 
-    // handy to sum up per thread histograms. #pragma omp simd speeds up the loop by about factor 3 for LUTu (uint32_t).
-    template<typename U = T, typename = typename std::enable_if<std::is_same<U, std::uint32_t>::value>::type>
-    LUT<T> & operator+=(const LUT<T>& rhs)
+    // handy to sum up per thread histograms. #pragma omp simd speeds up the
+    // loop by about factor 3 for LUTu (uint32_t).
+    template <typename U = T, typename = typename std::enable_if<
+                                  std::is_same<U, std::uint32_t>::value>::type>
+    LUT<T> &operator+=(const LUT<T> &rhs)
     {
         if (rhs.size == this->size) {
 #ifdef _OPENMP
-            #pragma omp simd
+#pragma omp simd
 #endif
 
-            for(unsigned int i = 0; i < this->size; i++) {
+            for (unsigned int i = 0; i < this->size; i++) {
                 data[i] += rhs.data[i];
             }
         }
@@ -274,14 +266,15 @@ public:
     }
 
     // multiply all elements of LUT<float> with a constant float value
-    template<typename U = T, typename = typename std::enable_if<std::is_same<U, float>::value>::type>
-    LUT<float> & operator*=(float factor)
+    template <typename U = T, typename = typename std::enable_if<
+                                  std::is_same<U, float>::value>::type>
+    LUT<float> &operator*=(float factor)
     {
 #ifdef _OPENMP
-        #pragma omp simd
+#pragma omp simd
 #endif
 
-        for(unsigned int i = 0; i < this->size; i++) {
+        for (unsigned int i = 0; i < this->size; i++) {
             data[i] *= factor;
         }
 
@@ -289,52 +282,56 @@ public:
     }
 
     // divide all elements of LUT<float> by a constant float value
-    template<typename U = T, typename = typename std::enable_if<std::is_same<U, float>::value>::type>
-    LUT<float> & operator/=(float divisor)
+    template <typename U = T, typename = typename std::enable_if<
+                                  std::is_same<U, float>::value>::type>
+    LUT<float> &operator/=(float divisor)
     {
 #ifdef _OPENMP
-        #pragma omp simd
+#pragma omp simd
 #endif
 
-        for(unsigned int i = 0; i < this->size; i++) {
+        for (unsigned int i = 0; i < this->size; i++) {
             data[i] /= divisor;
         }
 
         return *this;
     }
 
-
     // use with integer indices
-    T& operator[](int index) const
+    T &operator[](int index) const
     {
-        return data[ rtengine::LIM<int>(index, 0, upperBound) ];
+        return data[rtengine::LIM<int>(index, 0, upperBound)];
     }
 
 #ifdef __SSE2__
 
-
     // NOTE: This function requires LUTs which clips only at lower bound
     vfloat cb(vfloat indexv) const
     {
-        static_assert(std::is_same<T, float>::value, "This method only works for float LUTs");
+        static_assert(std::is_same<T, float>::value,
+                      "This method only works for float LUTs");
 
-        // Clamp and convert to integer values. Extract out of SSE register because all
-        // lookup operations use regular addresses.
-        vfloat clampedIndexes = vclampf(indexv, ZEROV, maxsv); // this automagically uses ZEROV in case indexv is NaN
+        // Clamp and convert to integer values. Extract out of SSE register
+        // because all lookup operations use regular addresses.
+        vfloat clampedIndexes = vclampf(
+            indexv, ZEROV,
+            maxsv); // this automagically uses ZEROV in case indexv is NaN
         vint indexes = _mm_cvttps_epi32(clampedIndexes);
         int indexArray[4];
-        _mm_storeu_si128(reinterpret_cast<__m128i*>(&indexArray[0]), indexes);
+        _mm_storeu_si128(reinterpret_cast<__m128i *>(&indexArray[0]), indexes);
 
-        // Load data from the table. This reads more than necessary, but there don't seem
-        // to exist more granular operations (though we could try non-SSE).
-        // Cast to int for convenience in the next operation (partial transpose).
+        // Load data from the table. This reads more than necessary, but there
+        // don't seem to exist more granular operations (though we could try
+        // non-SSE). Cast to int for convenience in the next operation (partial
+        // transpose).
         vint values[4];
         for (int i = 0; i < 4; ++i) {
             values[i] = _mm_castps_si128(LVFU(data[indexArray[i]]));
         }
 
-        // Partial 4x4 transpose operation. We want two new vectors, the first consisting
-        // of [values[0][0] ... values[3][0]] and the second [values[0][1] ... values[3][1]].
+        // Partial 4x4 transpose operation. We want two new vectors, the first
+        // consisting of [values[0][0] ... values[3][0]] and the second
+        // [values[0][1] ... values[3][1]].
         __m128i temp0 = _mm_unpacklo_epi32(values[0], values[1]);
         __m128i temp1 = _mm_unpacklo_epi32(values[2], values[3]);
         vfloat lower = _mm_castsi128_ps(_mm_unpacklo_epi64(temp0, temp1));
@@ -348,56 +345,70 @@ public:
     // (which is the default).
     vfloat operator[](vfloat indexv) const
     {
-        static_assert(std::is_same<T, float>::value, "This method only works for float LUTs");
+        static_assert(std::is_same<T, float>::value,
+                      "This method only works for float LUTs");
 
-        // Clamp and convert to integer values. Extract out of SSE register because all
-        // lookup operations use regular addresses.
-        vfloat clampedIndexes = vclampf(indexv, ZEROV, maxsv); // this automagically uses ZEROV in case indexv is NaN
+        // Clamp and convert to integer values. Extract out of SSE register
+        // because all lookup operations use regular addresses.
+        vfloat clampedIndexes = vclampf(
+            indexv, ZEROV,
+            maxsv); // this automagically uses ZEROV in case indexv is NaN
         vint indexes = _mm_cvttps_epi32(clampedIndexes);
         int indexArray[4];
-        _mm_storeu_si128(reinterpret_cast<__m128i*>(&indexArray[0]), indexes);
+        _mm_storeu_si128(reinterpret_cast<__m128i *>(&indexArray[0]), indexes);
 
-        // Load data from the table. This reads more than necessary, but there don't seem
-        // to exist more granular operations (though we could try non-SSE).
-        // Cast to int for convenience in the next operation (partial transpose).
+        // Load data from the table. This reads more than necessary, but there
+        // don't seem to exist more granular operations (though we could try
+        // non-SSE). Cast to int for convenience in the next operation (partial
+        // transpose).
         vint values[4];
         for (int i = 0; i < 4; ++i) {
             values[i] = _mm_castps_si128(LVFU(data[indexArray[i]]));
         }
 
-        // Partial 4x4 transpose operation. We want two new vectors, the first consisting
-        // of [values[0][0] ... values[3][0]] and the second [values[0][1] ... values[3][1]].
+        // Partial 4x4 transpose operation. We want two new vectors, the first
+        // consisting of [values[0][0] ... values[3][0]] and the second
+        // [values[0][1] ... values[3][1]].
         __m128i temp0 = _mm_unpacklo_epi32(values[0], values[1]);
         __m128i temp1 = _mm_unpacklo_epi32(values[2], values[3]);
         vfloat lower = _mm_castsi128_ps(_mm_unpacklo_epi64(temp0, temp1));
         vfloat upper = _mm_castsi128_ps(_mm_unpackhi_epi64(temp0, temp1));
 
-        vfloat diff = vclampf(indexv, ZEROV, sizev) - _mm_cvtepi32_ps(indexes); // this automagically uses ZEROV in case indexv is NaN
+        vfloat diff =
+            vclampf(indexv, ZEROV, sizev) -
+            _mm_cvtepi32_ps(
+                indexes); // this automagically uses ZEROV in case indexv is NaN
         return vintpf(diff, upper, lower);
     }
 
-    // NOTE: This version requires LUTs which do not clip at upper and lower bounds
+    // NOTE: This version requires LUTs which do not clip at upper and lower
+    // bounds
     vfloat operator()(vfloat indexv) const
     {
-        static_assert(std::is_same<T, float>::value, "This method only works for float LUTs");
+        static_assert(std::is_same<T, float>::value,
+                      "This method only works for float LUTs");
 
-        // Clamp and convert to integer values. Extract out of SSE register because all
-        // lookup operations use regular addresses.
-        vfloat clampedIndexes = vclampf(indexv, ZEROV, maxsv); // this automagically uses ZEROV in case indexv is NaN
+        // Clamp and convert to integer values. Extract out of SSE register
+        // because all lookup operations use regular addresses.
+        vfloat clampedIndexes = vclampf(
+            indexv, ZEROV,
+            maxsv); // this automagically uses ZEROV in case indexv is NaN
         vint indexes = _mm_cvttps_epi32(clampedIndexes);
         int indexArray[4];
-        _mm_storeu_si128(reinterpret_cast<__m128i*>(&indexArray[0]), indexes);
+        _mm_storeu_si128(reinterpret_cast<__m128i *>(&indexArray[0]), indexes);
 
-        // Load data from the table. This reads more than necessary, but there don't seem
-        // to exist more granular operations (though we could try non-SSE).
-        // Cast to int for convenience in the next operation (partial transpose).
+        // Load data from the table. This reads more than necessary, but there
+        // don't seem to exist more granular operations (though we could try
+        // non-SSE). Cast to int for convenience in the next operation (partial
+        // transpose).
         vint values[4];
         for (int i = 0; i < 4; ++i) {
             values[i] = _mm_castps_si128(LVFU(data[indexArray[i]]));
         }
 
-        // Partial 4x4 transpose operation. We want two new vectors, the first consisting
-        // of [values[0][0] ... values[3][0]] and the second [values[0][1] ... values[3][1]].
+        // Partial 4x4 transpose operation. We want two new vectors, the first
+        // consisting of [values[0][0] ... values[3][0]] and the second
+        // [values[0][1] ... values[3][1]].
         __m128i temp0 = _mm_unpacklo_epi32(values[0], values[1]);
         __m128i temp1 = _mm_unpacklo_epi32(values[2], values[3]);
         vfloat lower = _mm_castsi128_ps(_mm_unpacklo_epi64(temp0, temp1));
@@ -407,36 +418,53 @@ public:
         return vintpf(diff, upper, lower);
     }
 
-    // vectorized LUT access with integer indices. Clips at lower and upper bounds
+    // vectorized LUT access with integer indices. Clips at lower and upper
+    // bounds
 #ifdef __SSE4_1__
-    template<typename U = T, typename = typename std::enable_if<std::is_same<U, float>::value>::type>
+    template <typename U = T, typename = typename std::enable_if<
+                                  std::is_same<U, float>::value>::type>
     vfloat operator[](vint idxv) const
     {
-        idxv = _mm_max_epi32( _mm_setzero_si128(), _mm_min_epi32(idxv, sizeiv));
-        // access the LUT 4 times. Trust the compiler. It generates good code here, better than hand written SSE code
-        return _mm_setr_ps(data[_mm_extract_epi32(idxv,0)], data[_mm_extract_epi32(idxv,1)], data[_mm_extract_epi32(idxv,2)], data[_mm_extract_epi32(idxv,3)]);
+        idxv = _mm_max_epi32(_mm_setzero_si128(), _mm_min_epi32(idxv, sizeiv));
+        // access the LUT 4 times. Trust the compiler. It generates good code
+        // here, better than hand written SSE code
+        return _mm_setr_ps(
+            data[_mm_extract_epi32(idxv, 0)], data[_mm_extract_epi32(idxv, 1)],
+            data[_mm_extract_epi32(idxv, 2)], data[_mm_extract_epi32(idxv, 3)]);
     }
 #else
-    template<typename U = T, typename = typename std::enable_if<std::is_same<U, float>::value>::type>
+    template <typename U = T, typename = typename std::enable_if<
+                                  std::is_same<U, float>::value>::type>
     vfloat operator[](vint idxv) const
     {
         // convert to float because SSE2 has no min/max for 32bit integers
-        vfloat tempv = vclampf(_mm_cvtepi32_ps(idxv), ZEROV, sizev); // this automagically uses ZEROV in case idxv is NaN (which will never happen because it is a vector of int)
+        vfloat tempv = vclampf(
+            _mm_cvtepi32_ps(idxv), ZEROV,
+            sizev); // this automagically uses ZEROV in case idxv is NaN (which
+                    // will never happen because it is a vector of int)
         idxv = _mm_cvttps_epi32(tempv);
-        // access the LUT 4 times. Trust the compiler. It generates good code here, better than hand written SSE code
+        // access the LUT 4 times. Trust the compiler. It generates good code
+        // here, better than hand written SSE code
         return _mm_setr_ps(data[_mm_cvtsi128_si32(idxv)],
-                           data[_mm_cvtsi128_si32(_mm_shuffle_epi32(idxv, _MM_SHUFFLE(1, 1, 1, 1)))],
-                           data[_mm_cvtsi128_si32(_mm_shuffle_epi32(idxv, _MM_SHUFFLE(2, 2, 2, 2)))],
-                           data[_mm_cvtsi128_si32(_mm_shuffle_epi32(idxv, _MM_SHUFFLE(3, 3, 3, 3)))]);
+                           data[_mm_cvtsi128_si32(_mm_shuffle_epi32(
+                               idxv, _MM_SHUFFLE(1, 1, 1, 1)))],
+                           data[_mm_cvtsi128_si32(_mm_shuffle_epi32(
+                               idxv, _MM_SHUFFLE(2, 2, 2, 2)))],
+                           data[_mm_cvtsi128_si32(_mm_shuffle_epi32(
+                               idxv, _MM_SHUFFLE(3, 3, 3, 3)))]);
     }
 #endif
 #endif
 
     // use with float indices
-    template<typename U = T, typename V, typename = typename std::enable_if<std::is_floating_point<V>::value && std::is_same<U, float>::value>::type>
+    template <
+        typename U = T, typename V,
+        typename = typename std::enable_if<std::is_floating_point<V>::value &&
+                                           std::is_same<U, float>::value>::type>
     T operator[](V index) const
     {
-        int idx = (int)index;  // don't use floor! The difference in negative space is no problems here
+        int idx = (int)index; // don't use floor! The difference in negative
+                              // space is no problems here
 
         if (index < 0.f || !(index == index) /* check for NaN */) {
             if (clip & LUT_CLIP_BELOW) {
@@ -452,18 +480,20 @@ public:
             idx = maxs;
         }
 
-        float diff = index - (float) idx;
+        float diff = index - (float)idx;
         T p1 = data[idx];
         T p2 = data[idx + 1] - p1;
         return (p1 + p2 * diff);
     }
 
     // Return the value for "index" that is in the [0-1] range.
-    template<typename U = T, typename = typename std::enable_if<std::is_same<U, float>::value>::type>
-    T getVal01 (float index) const
+    template <typename U = T, typename = typename std::enable_if<
+                                  std::is_same<U, float>::value>::type>
+    T getVal01(float index) const
     {
         index *= (float)upperBound;
-        int idx = (int)index;  // don't use floor! The difference in negative space is no problems here
+        int idx = (int)index; // don't use floor! The difference in negative
+                              // space is no problems here
 
         if (index < 0.f) {
             if (clip & LUT_CLIP_BELOW) {
@@ -479,19 +509,21 @@ public:
             idx = maxs;
         }
 
-        float diff = index - (float) idx;
+        float diff = index - (float)idx;
         T p1 = data[idx];
         T p2 = data[idx + 1] - p1;
         return (p1 + p2 * diff);
     }
 
 #ifndef NDEBUG
-    // Debug facility ; dump the content of the LUT in a file. No control of the filename is done
+    // Debug facility ; dump the content of the LUT in a file. No control of the
+    // filename is done
     void dump(Glib::ustring fname)
     {
         if (size) {
-            Glib::ustring fname_ = fname + ".xyz"; // TopSolid'Design "plot" file format
-            std::ofstream f (fname_.c_str());
+            Glib::ustring fname_ =
+                fname + ".xyz"; // TopSolid'Design "plot" file format
+            std::ofstream f(fname_.c_str());
             f << "$" << std::endl;
 
             for (unsigned int iter = 0; iter < size; iter++) {
@@ -499,16 +531,12 @@ public:
             }
 
             f << "$" << std::endl;
-            f.close ();
+            f.close();
         }
     }
 #endif
 
-
-    operator bool (void) const
-    {
-        return size > 0;
-    }
+    operator bool(void) const { return size > 0; }
 
     void clear(void)
     {
@@ -533,23 +561,27 @@ public:
         clip = 0;
     }
 
-    // create an identity LUT (LUT(x) = x) or a scaled identity LUT (LUT(x) = x / divisor)
-    template<typename U = T, typename = typename std::enable_if<std::is_same<U, float>::value>::type>
+    // create an identity LUT (LUT(x) = x) or a scaled identity LUT (LUT(x) = x
+    // / divisor)
+    template <typename U = T, typename = typename std::enable_if<
+                                  std::is_same<U, float>::value>::type>
     void makeIdentity(float divisor = 1.f)
     {
-        if(divisor == 1.f) {
-            for(unsigned int i = 0; i < size; i++) {
+        if (divisor == 1.f) {
+            for (unsigned int i = 0; i < size; i++) {
                 data[i] = i;
             }
         } else {
-            for(unsigned int i = 0; i < size; i++) {
+            for (unsigned int i = 0; i < size; i++) {
                 data[i] = i / divisor;
             }
         }
     }
 
-    // compress a LUT<uint32_t> with size y into a LUT<uint32_t> with size x (y>x)
-    template<typename U = T, typename = typename std::enable_if<std::is_same<U, std::uint32_t>::value>::type>
+    // compress a LUT<uint32_t> with size y into a LUT<uint32_t> with size x
+    // (y>x)
+    template <typename U = T, typename = typename std::enable_if<
+                                  std::is_same<U, std::uint32_t>::value>::type>
     void compressTo(LUT<T> &dest, unsigned int numVals = 0) const
     {
         numVals = numVals == 0 ? size : numVals;
@@ -559,28 +591,32 @@ public:
 
         for (unsigned int i = 0; i < numVals; i++) {
             int hi = (int)(mult * i);
-            dest.data[hi] += this->data[i] ;
+            dest.data[hi] += this->data[i];
         }
     }
 
-    // compress a LUT<uint32_t> with size y into a LUT<uint32_t> with size x (y>x) by using the passTrough LUT to calculate indexes
-    template<typename U = T, typename = typename std::enable_if<std::is_same<U, std::uint32_t>::value>::type>
-    void compressTo(LUT<T> &dest, unsigned int numVals, const LUT<float> &passThrough) const
+    // compress a LUT<uint32_t> with size y into a LUT<uint32_t> with size x
+    // (y>x) by using the passTrough LUT to calculate indexes
+    template <typename U = T, typename = typename std::enable_if<
+                                  std::is_same<U, std::uint32_t>::value>::type>
+    void compressTo(LUT<T> &dest, unsigned int numVals,
+                    const LUT<float> &passThrough) const
     {
-        if(passThrough) {
+        if (passThrough) {
             numVals = std::min(numVals, size);
             numVals = std::min(numVals, passThrough.getSize());
             float mult = dest.size - 1;
 
             for (unsigned int i = 0; i < numVals; i++) {
                 int hi = (int)(mult * passThrough[i]);
-                dest[hi] += this->data[i] ;
+                dest[hi] += this->data[i];
             }
         }
     }
 
     // compute sum and average of a LUT<uint32_t>
-    template<typename U = T, typename = typename std::enable_if<std::is_same<U, std::uint32_t>::value>::type>
+    template <typename U = T, typename = typename std::enable_if<
+                                  std::is_same<U, std::uint32_t>::value>::type>
     void getSumAndAverage(float &sum, float &avg) const
     {
         sum = 0.f;
@@ -592,12 +628,11 @@ public:
         vint sumv = (vint)ZEROV;
         vfloat avgv = ZEROV;
 
-        for(; i < static_cast<int>(size) - 3; i += 4) {
-            vint datav = _mm_loadu_si128((__m128i*)&data[i]);
+        for (; i < static_cast<int>(size) - 3; i += 4) {
+            vint datav = _mm_loadu_si128((__m128i *)&data[i]);
             sumv += datav;
             avgv += iv * _mm_cvtepi32_ps(datav);
             iv += fourv;
-
         }
 
         sum = vhadd(_mm_cvtepi32_ps(sumv));
@@ -613,26 +648,28 @@ public:
         avg /= sum;
     }
 
-
-    template<typename U = T, typename = typename std::enable_if<std::is_same<U, float>::value>::type>
+    template <typename U = T, typename = typename std::enable_if<
+                                  std::is_same<U, float>::value>::type>
     void makeConstant(float value, unsigned int numVals = 0)
     {
         numVals = numVals == 0 ? size : numVals;
         numVals = std::min(numVals, size);
 
-        for(unsigned int i = 0; i < numVals; i++) {
+        for (unsigned int i = 0; i < numVals; i++) {
             data[i] = value;
         }
     }
 
-    // share the buffer with another LUT, handy for same data but different clip flags
-    void share(const LUT<T> &source, int flags = LUT_CLIP_BELOW | LUT_CLIP_ABOVE)
+    // share the buffer with another LUT, handy for same data but different clip
+    // flags
+    void share(const LUT<T> &source,
+               int flags = LUT_CLIP_BELOW | LUT_CLIP_ABOVE)
     {
         if (owner && data) {
             delete[] data;
         }
 
-        dirty = false;  // Assumption
+        dirty = false; // Assumption
         clip = flags;
         data = source.data;
         owner = 0;
@@ -641,13 +678,11 @@ public:
         maxs = size - 2;
         maxsf = (float)maxs;
 #ifdef __SSE2__
-        maxsv =  F2V( size - 2);
-        sizeiv =  _mm_set1_epi32( (int)(size - 1) );
-        sizev = F2V( size - 1 );
+        maxsv = F2V(size - 2);
+        sizeiv = _mm_set1_epi32((int)(size - 1));
+        sizev = F2V(size - 1);
 #endif
     }
-
-
 };
 
 #endif /* LUT_H_ */
