@@ -1,5 +1,5 @@
 /* -*- C++ -*-
- *  
+ *
  *  This file is part of RawTherapee.
  *
  *  Copyright (c) 2004-2010 Gabor Horvath <hgabor@rawtherapee.com>
@@ -25,28 +25,28 @@
 
 #include <glibmm.h>
 
-#include "rt_math.h"
 #include "../rtgui/mycurve.h"
-#include "../rtgui/myflatcurve.h"
 #include "../rtgui/mydiagonalcurve.h"
+#include "../rtgui/myflatcurve.h"
 #include "color.h"
-#include "procparams.h"
 #include "pipettebuffer.h"
+#include "procparams.h"
+#include "rt_math.h"
 
 #include "LUT.h"
 
-#define CURVES_MIN_POLY_POINTS  1000
+#define CURVES_MIN_POLY_POINTS 1000
 
-#include "rt_math.h"
 #include "linalgebra.h"
+#include "rt_math.h"
 
-#define CLIPI(a) ((a)>0?((a)<65534?(a):65534):0)
+#define CLIPI(a) ((a) > 0 ? ((a) < 65534 ? (a) : 65534) : 0)
 
 namespace rtengine {
 
 class ToneCurve;
 
-bool sanitizeCurve(std::vector<double>& curve);
+bool sanitizeCurve(std::vector<double> &curve);
 
 namespace curves {
 
@@ -54,34 +54,33 @@ extern const std::vector<double> filmcurve_def;
 
 } // namespace curves
 
-
 class DiagonalCurve;
 
-
 class Curve {
     class HashEntry {
     public:
         unsigned short smallerValue;
         unsigned short higherValue;
     };
+
 protected:
     int N;
-    int ppn;            // targeted polyline point number
-    double* x;
-    double* y;
+    int ppn; // targeted polyline point number
+    double *x;
+    double *y;
     // begin of variables used in Parametric curves only
     double mc;
     double mfc;
     double msc;
     double mhc;
     // end of variables used in Parametric curves only
-    std::vector<double> poly_x;     // X points of the faceted curve
-    std::vector<double> poly_y;     // Y points of the faceted curve
+    std::vector<double> poly_x; // X points of the faceted curve
+    std::vector<double> poly_y; // Y points of the faceted curve
     std::vector<double> dyByDx;
     std::vector<HashEntry> hash;
-    unsigned short hashSize;        // hash table's size, between [10, 100, 1000]
+    unsigned short hashSize; // hash table's size, between [10, 100, 1000]
 
-    double* ypp;
+    double *ypp;
 
     // Fields for the elementary curve polygonisation
     double x1, y1, x2, y2, x3, y3;
@@ -89,30 +88,33 @@ protected:
     double increment;
     int nbr_points;
 
-    // basic convex function between (0,0) and (1,1). m1 and m2 controls the slope at the start and end point
-    static inline double basel (double x, double m1, double m2)
+    // basic convex function between (0,0) and (1,1). m1 and m2 controls the
+    // slope at the start and end point
+    static inline double basel(double x, double m1, double m2)
     {
         if (x == 0.0) {
             return 0.0;
         }
 
-        double k = sqrt ((m1 - 1.0) * (m1 - m2) * 0.5) / (1.0 - m2);
+        double k = sqrt((m1 - 1.0) * (m1 - m2) * 0.5) / (1.0 - m2);
         double l = (m1 - m2) / (1.0 - m2) + k;
         double lx = xlog(x);
         return m2 * x + (1.0 - m2) * (2.0 - xexp(k * lx)) * xexp(l * lx);
     }
-    
-    // basic concave function between (0,0) and (1,1). m1 and m2 controls the slope at the start and end point
-    static inline double baseu (double x, double m1, double m2)
+
+    // basic concave function between (0,0) and (1,1). m1 and m2 controls the
+    // slope at the start and end point
+    static inline double baseu(double x, double m1, double m2)
     {
         return 1.0 - basel(1.0 - x, m1, m2);
     }
-    
-    // convex curve between (0,0) and (1,1) with slope m at (0,0). hr controls the highlight recovery
-    static inline double cupper (double x, double m, double hr)
+
+    // convex curve between (0,0) and (1,1) with slope m at (0,0). hr controls
+    // the highlight recovery
+    static inline double cupper(double x, double m, double hr)
     {
         if (hr > 1.0) {
-            return baseu (x, m, 2.0 * (hr - 1.0) / m);
+            return baseu(x, m, 2.0 * (hr - 1.0) / m);
         }
 
         double x1 = (1.0 - hr) / m;
@@ -128,97 +130,95 @@ protected:
 
         return 1.0 - hr + hr * baseu((x - x1) / hr, m, 0);
     }
-    
-    static inline double clower (double x, double m, double sr)
+
+    static inline double clower(double x, double m, double sr)
     {
         return 1.0 - cupper(1.0 - x, m, sr);
     }
-    
-    static inline double p00 (double x, double prot)
+
+    static inline double p00(double x, double prot)
     {
         return clower(x, 2.0, prot);
     }
-    static inline double p11 (double x, double prot)
+    static inline double p11(double x, double prot)
     {
         return cupper(x, 2.0, prot);
     }
-    static inline double p01 (double x, double prot)
+    static inline double p01(double x, double prot)
     {
-        return x <= 0.5 ? clower(x * 2, 2.0, prot) * 0.5 : 0.5 + cupper((x - 0.5) * 2, 2.0, prot) * 0.5;
+        return x <= 0.5 ? clower(x * 2, 2.0, prot) * 0.5
+                        : 0.5 + cupper((x - 0.5) * 2, 2.0, prot) * 0.5;
     }
-    static inline double p10 (double x, double prot)
+    static inline double p10(double x, double prot)
     {
-        return x <= 0.5 ? cupper(x * 2, 2.0, prot) * 0.5 : 0.5 + clower ((x - 0.5) * 2, 2.0, prot) * 0.5;
+        return x <= 0.5 ? cupper(x * 2, 2.0, prot) * 0.5
+                        : 0.5 + clower((x - 0.5) * 2, 2.0, prot) * 0.5;
     }
-    static inline double pfull (double x, double prot, double sh, double hl)
+    static inline double pfull(double x, double prot, double sh, double hl)
     {
-        return (1 - sh) * (1 - hl) * p00(x, prot) + sh * hl * p11(x, prot) + (1 - sh) * hl * p01(x, prot) + sh * (1 - hl) * p10(x, prot);
+        return (1 - sh) * (1 - hl) * p00(x, prot) + sh * hl * p11(x, prot) +
+               (1 - sh) * hl * p01(x, prot) + sh * (1 - hl) * p10(x, prot);
     }
 
     void fillHash();
     void fillDyByDx();
 
 public:
-    Curve ();
-    virtual ~Curve () {};
-    void AddPolygons ();
-    int getSize () const; // return the number of control points
+    Curve();
+    virtual ~Curve() {};
+    void AddPolygons();
+    int getSize() const; // return the number of control points
     void getControlPoint(int cpNum, double &x, double &y) const;
-    virtual double getVal (double t) const = 0;
-    virtual void   getVal (const std::vector<double>& t, std::vector<double>& res) const = 0;
+    virtual double getVal(double t) const = 0;
+    virtual void getVal(const std::vector<double> &t,
+                        std::vector<double> &res) const = 0;
 
-    virtual bool   isIdentity () const = 0;
+    virtual bool isIdentity() const = 0;
 };
 
-class DiagonalCurve : public Curve
-{
+class DiagonalCurve: public Curve {
 
 protected:
     DiagonalCurveType kind;
 
-    void spline_cubic_set ();
+    void spline_cubic_set();
     void catmull_rom_set();
-    void NURBS_set ();
+    void NURBS_set();
 
 public:
-    DiagonalCurve (const std::vector<double>& points, int ppn = CURVES_MIN_POLY_POINTS);
-    ~DiagonalCurve () override;
+    DiagonalCurve(const std::vector<double> &points,
+                  int ppn = CURVES_MIN_POLY_POINTS);
+    ~DiagonalCurve() override;
 
-    double getVal     (double t) const override;
-    void   getVal     (const std::vector<double>& t, std::vector<double>& res) const override;
-    bool   isIdentity () const override
-    {
-        return kind == DCT_Empty;
-    };
+    double getVal(double t) const override;
+    void getVal(const std::vector<double> &t,
+                std::vector<double> &res) const override;
+    bool isIdentity() const override { return kind == DCT_Empty; };
 };
 
-class FlatCurve : public Curve
-{
+class FlatCurve: public Curve {
 
 private:
     FlatCurveType kind;
-    double* leftTangent;
-    double* rightTangent;
+    double *leftTangent;
+    double *rightTangent;
     double identityValue;
     bool periodic;
 
-    void CtrlPoints_set ();
+    void CtrlPoints_set();
 
 public:
+    FlatCurve(const std::vector<double> &points, bool isPeriodic = true,
+              int ppn = CURVES_MIN_POLY_POINTS);
+    ~FlatCurve() override;
 
-    FlatCurve (const std::vector<double>& points, bool isPeriodic = true, int ppn = CURVES_MIN_POLY_POINTS);
-    ~FlatCurve () override;
-
-    double getVal     (double t) const override;
-    void   getVal     (const std::vector<double>& t, std::vector<double>& res) const override;
-    bool   setIdentityValue (double iVal);
-    bool   isIdentity () const override
-    {
-        return kind == FCT_Empty;
-    };
+    double getVal(double t) const override;
+    void getVal(const std::vector<double> &t,
+                std::vector<double> &res) const override;
+    bool setIdentityValue(double iVal);
+    bool isIdentity() const override { return kind == FCT_Empty; };
 };
 
-
 namespace curves {
 
 inline void setLutVal(const LUTf &lut, const Curve *curve, float &val)
@@ -232,10 +232,9 @@ inline void setLutVal(const LUTf &lut, const Curve *curve, float &val)
 
 } // namespace curves
 
-
 class ToneCurve {
 public:
-    LUTf lutToneCurve;  // 0xffff range
+    LUTf lutToneCurve; // 0xffff range
     float whitecoeff;
     float whitept;
     const Curve *curve;
@@ -244,18 +243,13 @@ public:
     virtual ~ToneCurve() {};
 
     void Reset();
-    void Set(const Curve &pCurve, float whitecoeff=1.f);
-    operator bool (void) const
-    {
-        return lutToneCurve;
-    }
+    void Set(const Curve &pCurve, float whitecoeff = 1.f);
+    operator bool(void) const { return lutToneCurve; }
 };
 
-
-class StandardToneCurve : public ToneCurve
-{
+class StandardToneCurve: public ToneCurve {
 public:
-    void Apply(float& r, float& g, float& b) const;
+    void Apply(float &r, float &g, float &b) const;
 
     // Applies the tone curve to `r`, `g`, `b` arrays, starting at `r[start]`
     // and ending at `r[end]` (and respectively for `b` and `g`). Uses SSE
@@ -265,42 +259,38 @@ public:
     //         float *r, float *g, float *b) const;
 };
 
-class AdobeToneCurve : public ToneCurve
-{
+class AdobeToneCurve: public ToneCurve {
 private:
-    void RGBTone(float& r, float& g, float& b) const;  // helper for tone curve
+    void RGBTone(float &r, float &g, float &b) const; // helper for tone curve
 
 public:
-    void Apply(float& r, float& g, float& b) const;
+    void Apply(float &r, float &g, float &b) const;
 };
 
-class SatAndValueBlendingToneCurve : public ToneCurve
-{
+class SatAndValueBlendingToneCurve: public ToneCurve {
 public:
-    void Apply(float& r, float& g, float& b) const;
+    void Apply(float &r, float &g, float &b) const;
 };
 
-class WeightedStdToneCurve : public ToneCurve
-{
+class WeightedStdToneCurve: public ToneCurve {
 private:
     float Triangle(float refX, float refY, float X2) const;
-// #ifdef __SSE2__
-//     vfloat Triangle(vfloat refX, vfloat refY, vfloat X2) const;
-// #endif
+    // #ifdef __SSE2__
+    //     vfloat Triangle(vfloat refX, vfloat refY, vfloat X2) const;
+    // #endif
 public:
-    void Apply(float& r, float& g, float& b) const;
-    //void BatchApply(const size_t start, const size_t end, float *r, float *g, float *b) const;
+    void Apply(float &r, float &g, float &b) const;
+    // void BatchApply(const size_t start, const size_t end, float *r, float *g,
+    // float *b) const;
 };
 
-class LuminanceToneCurve : public ToneCurve
-{
+class LuminanceToneCurve: public ToneCurve {
 public:
     // void Apply(float& r, float& g, float& b) const;
-    void Apply(float& r, float& g, float& b, const float ws[3][3]) const;
+    void Apply(float &r, float &g, float &b, const float ws[3][3]) const;
 };
 
-class PerceptualToneCurveState
-{
+class PerceptualToneCurveState {
 public:
     float Working2Prophoto[3][3];
     float Prophoto2Working[3][3];
@@ -309,12 +299,12 @@ public:
     float strength;
 };
 
-// Tone curve whose purpose is to keep the color appearance constant, that is the curve changes contrast
-// but colors appears to have the same hue and saturation as before. As contrast and saturation is tightly
-// coupled in human vision saturation is modulated based on the curve's contrast, and that way the appearance
-// can be kept perceptually constant (within limits).
-class PerceptualToneCurve : public ToneCurve
-{
+// Tone curve whose purpose is to keep the color appearance constant, that is
+// the curve changes contrast but colors appears to have the same hue and
+// saturation as before. As contrast and saturation is tightly coupled in human
+// vision saturation is modulated based on the curve's contrast, and that way
+// the appearance can be kept perceptually constant (within limits).
+class PerceptualToneCurve: public ToneCurve {
 private:
     static float cf_range[2];
     static float cf[1000];
@@ -322,18 +312,25 @@ private:
     static float f, c, nc, yb, la, xw, yw, zw;
     static float n, d, nbb, ncb, cz, aw, wh, pfl, fl, pow1;
 
-    static void cubic_spline(const float x[], const float y[], const int len, const float out_x[], float out_y[], const int out_len);
-    static float find_minimum_interval_halving(float (*func)(float x, void *arg), void *arg, float a, float b, float tol, int nmax);
+    static void cubic_spline(const float x[], const float y[], const int len,
+                             const float out_x[], float out_y[],
+                             const int out_len);
+    static float
+    find_minimum_interval_halving(float (*func)(float x, void *arg), void *arg,
+                                  float a, float b, float tol, int nmax);
     static float find_tc_slope_fun(float k, void *arg);
-    static float get_curve_val(float x, float range[2], float lut[], size_t lut_size);
+    static float get_curve_val(float x, float range[2], float lut[],
+                               size_t lut_size);
     float calculateToneCurveContrastValue() const;
+
 public:
     static void init();
-    void initApplyState(PerceptualToneCurveState & state, const Glib::ustring &workingSpace) const;
-    void BatchApply(const size_t start, const size_t end, float *r, float *g, float *b, const PerceptualToneCurveState &state) const;
+    void initApplyState(PerceptualToneCurveState &state,
+                        const Glib::ustring &workingSpace) const;
+    void BatchApply(const size_t start, const size_t end, float *r, float *g,
+                    float *b, const PerceptualToneCurveState &state) const;
 };
 
-
 class NeutralToneCurve: public ToneCurve {
 public:
     struct ApplyState {
@@ -348,19 +345,20 @@ public:
         float yhue;
         float rrange;
         float brange;
-        float yrange;        
-        
-        explicit ApplyState(const Glib::ustring &workingSpace, const Glib::ustring &outprofile, const Curve *base);
+        float yrange;
+
+        explicit ApplyState(const Glib::ustring &workingSpace,
+                            const Glib::ustring &outprofile, const Curve *base);
     };
-    void BatchApply(const size_t start, const size_t end, float *r, float *g, float *b, const ApplyState &state) const;
+    void BatchApply(const size_t start, const size_t end, float *r, float *g,
+                    float *b, const ApplyState &state) const;
 };
 
-
 // Standard tone curve
-inline void StandardToneCurve::Apply (float& r, float& g, float& b) const
+inline void StandardToneCurve::Apply(float &r, float &g, float &b) const
 {
 
-    assert (lutToneCurve);
+    assert(lutToneCurve);
 
     curves::setLutVal(lutToneCurve, curve, r);
     curves::setLutVal(lutToneCurve, curve, g);
@@ -374,21 +372,25 @@ inline void StandardToneCurve::Apply (float& r, float& g, float& b) const
 //     assert (lutToneCurve.getClip() & LUT_CLIP_BELOW);
 //     assert (lutToneCurve.getClip() & LUT_CLIP_ABOVE);
 
-//     // All pointers must have the same alignment for SSE usage. In the loop body below,
-//     // we will only check `r`, assuming that the same result would hold for `g` and `b`.
-//     assert (reinterpret_cast<uintptr_t>(r) % 16 == reinterpret_cast<uintptr_t>(g) % 16);
-//     assert (reinterpret_cast<uintptr_t>(g) % 16 == reinterpret_cast<uintptr_t>(b) % 16);
+//     // All pointers must have the same alignment for SSE usage. In the loop
+//     body below,
+//     // we will only check `r`, assuming that the same result would hold for
+//     `g` and `b`. assert (reinterpret_cast<uintptr_t>(r) % 16 ==
+//     reinterpret_cast<uintptr_t>(g) % 16); assert
+//     (reinterpret_cast<uintptr_t>(g) % 16 == reinterpret_cast<uintptr_t>(b) %
+//     16);
 
 //     size_t i = start;
 //     while (true) {
 //         if (i >= end) {
-//             // If we get to the end before getting to an aligned address, just return.
+//             // If we get to the end before getting to an aligned address,
+//             just return.
 //             // (Or, for non-SSE mode, if we get to the end.)
 //             return;
 // #ifdef __SSE2__
 //         } else if (reinterpret_cast<uintptr_t>(&r[i]) % 16 == 0) {
-//             // Otherwise, we get to the first aligned address; go to the SSE part.
-//             break;
+//             // Otherwise, we get to the first aligned address; go to the SSE
+//             part. break;
 // #endif
 //         }
 //         r[i] = lutToneCurve[r[i]];
@@ -422,22 +424,22 @@ inline void StandardToneCurve::Apply (float& r, float& g, float& b) const
 // Tone curve according to Adobe's reference implementation
 // values in 0xffff space
 // inlined to make sure there will be no cache flush when used
-inline void AdobeToneCurve::Apply (float& ir, float& ig, float& ib) const
+inline void AdobeToneCurve::Apply(float &ir, float &ig, float &ib) const
 {
 
-    assert (lutToneCurve);
+    assert(lutToneCurve);
     float r = LIM<float>(ir, 0.f, whitept);
     float g = LIM<float>(ig, 0.f, whitept);
     float b = LIM<float>(ib, 0.f, whitept);
 
     if (r >= g) {
-        if      (g > b) {
-            RGBTone (r, g, b);    // Case 1: r >= g >  b
+        if (g > b) {
+            RGBTone(r, g, b); // Case 1: r >= g >  b
         } else if (b > r) {
-            RGBTone (b, r, g);    // Case 2: b >  r >= g
+            RGBTone(b, r, g); // Case 2: b >  r >= g
         } else if (b > g) {
-            RGBTone (r, b, g);    // Case 3: r >= b >  g
-        } else {                           // Case 4: r >= g == b
+            RGBTone(r, b, g); // Case 3: r >= b >  g
+        } else {              // Case 4: r >= g == b
             // r = lutToneCurve[r];
             // g = lutToneCurve[g];
             curves::setLutVal(lutToneCurve, curve, r);
@@ -445,12 +447,12 @@ inline void AdobeToneCurve::Apply (float& ir, float& ig, float& ib) const
             b = g;
         }
     } else {
-        if      (r >= b) {
-            RGBTone (g, r, b);    // Case 5: g >  r >= b
-        } else if (b >  g) {
-            RGBTone (b, g, r);    // Case 6: b >  g >  r
+        if (r >= b) {
+            RGBTone(g, r, b); // Case 5: g >  r >= b
+        } else if (b > g) {
+            RGBTone(b, g, r); // Case 6: b >  g >  r
         } else {
-            RGBTone (g, b, r);    // Case 7: g >= b >  r
+            RGBTone(g, b, r); // Case 7: g >= b >  r
         }
     }
 
@@ -459,7 +461,7 @@ inline void AdobeToneCurve::Apply (float& ir, float& ig, float& ib) const
     ib = b;
 }
 
-inline void AdobeToneCurve::RGBTone (float& r, float& g, float& b) const
+inline void AdobeToneCurve::RGBTone(float &r, float &g, float &b) const
 {
     float rold = r, gold = g, bold = b;
 
@@ -471,18 +473,20 @@ inline void AdobeToneCurve::RGBTone (float& r, float& g, float& b) const
 }
 
 // Modifying the Luminance channel only
-inline void LuminanceToneCurve::Apply(float &ir, float &ig, float &ib, const float ws[3][3]) const
+inline void LuminanceToneCurve::Apply(float &ir, float &ig, float &ib,
+                                      const float ws[3][3]) const
 {
-    assert (lutToneCurve);
+    assert(lutToneCurve);
 
     float r = LIM<float>(ir, 0.f, whitept);
     float g = LIM<float>(ig, 0.f, whitept);
     float b = LIM<float>(ib, 0.f, whitept);
 
-//    float currLuminance = r * 0.2126729f + g * 0.7151521f + b * 0.0721750f;
+    //    float currLuminance = r * 0.2126729f + g * 0.7151521f + b *
+    //    0.0721750f;
     float currLuminance = Color::rgbLuminance(r, g, b, ws);
     float newLuminance = currLuminance;
-    //lutToneCurve[currLuminance];
+    // lutToneCurve[currLuminance];
     curves::setLutVal(lutToneCurve, curve, newLuminance);
     currLuminance = currLuminance == 0.f ? 0.00001f : currLuminance;
     const float coef = newLuminance / currLuminance;
@@ -495,7 +499,6 @@ inline void LuminanceToneCurve::Apply(float &ir, float &ig, float &ib, const flo
     ib = b;
 }
 
-
 inline float WeightedStdToneCurve::Triangle(float a, float a1, float b) const
 {
     if (a != b) {
@@ -503,8 +506,8 @@ inline float WeightedStdToneCurve::Triangle(float a, float a1, float b) const
         float a2 = a1 - a;
 
         if (b < a) {
-            b1 = b + a2 *      b  /     a ;
-        } else       {
+            b1 = b + a2 * b / a;
+        } else {
             b1 = b + a2 * (whitept - b) / (whitept - a);
         }
 
@@ -515,7 +518,8 @@ inline float WeightedStdToneCurve::Triangle(float a, float a1, float b) const
 }
 
 // #ifdef __SSE2__
-// inline vfloat WeightedStdToneCurve::Triangle(vfloat a, vfloat a1, vfloat b) const
+// inline vfloat WeightedStdToneCurve::Triangle(vfloat a, vfloat a1, vfloat b)
+// const
 // {
 //         vmask eqmask = vmaskf_eq(b, a);
 //         vfloat a2 = a1 - a;
@@ -528,26 +532,26 @@ inline float WeightedStdToneCurve::Triangle(float a, float a1, float b) const
 
 // Tone curve modifying the value channel only, preserving hue and saturation
 // values in 0xffff space
-inline void WeightedStdToneCurve::Apply (float& ir, float& ig, float& ib) const
+inline void WeightedStdToneCurve::Apply(float &ir, float &ig, float &ib) const
 {
 
-    assert (lutToneCurve);
+    assert(lutToneCurve);
 
     float r = LIM<float>(ir, 0.f, whitept);
     float g = LIM<float>(ig, 0.f, whitept);
     float b = LIM<float>(ib, 0.f, whitept);
-    //float r1 = lutToneCurve[r];
+    // float r1 = lutToneCurve[r];
     float r1 = r;
     curves::setLutVal(lutToneCurve, curve, r1);
     float g1 = Triangle(r, r1, g);
     float b1 = Triangle(r, r1, b);
 
-    float g2 = g;//lutToneCurve[g];
+    float g2 = g; // lutToneCurve[g];
     curves::setLutVal(lutToneCurve, curve, g2);
     float r2 = Triangle(g, g2, r);
     float b2 = Triangle(g, g2, b);
 
-    float b3 = b;//lutToneCurve[b];
+    float b3 = b; // lutToneCurve[b];
     curves::setLutVal(lutToneCurve, curve, b3);
     float r3 = Triangle(b, b3, r);
     float g3 = Triangle(b, b3, g);
@@ -561,26 +565,31 @@ inline void WeightedStdToneCurve::Apply (float& ir, float& ig, float& ib) const
     ib = b;
 }
 
-// inline void WeightedStdToneCurve::BatchApply(const size_t start, const size_t end, float *r, float *g, float *b) const {
+// inline void WeightedStdToneCurve::BatchApply(const size_t start, const size_t
+// end, float *r, float *g, float *b) const {
 //     assert (lutToneCurve);
 //     assert (lutToneCurve.getClip() & LUT_CLIP_BELOW);
 //     assert (lutToneCurve.getClip() & LUT_CLIP_ABOVE);
 
-//     // All pointers must have the same alignment for SSE usage. In the loop body below,
-//     // we will only check `r`, assuming that the same result would hold for `g` and `b`.
-//     assert (reinterpret_cast<uintptr_t>(r) % 16 == reinterpret_cast<uintptr_t>(g) % 16);
-//     assert (reinterpret_cast<uintptr_t>(g) % 16 == reinterpret_cast<uintptr_t>(b) % 16);
+//     // All pointers must have the same alignment for SSE usage. In the loop
+//     body below,
+//     // we will only check `r`, assuming that the same result would hold for
+//     `g` and `b`. assert (reinterpret_cast<uintptr_t>(r) % 16 ==
+//     reinterpret_cast<uintptr_t>(g) % 16); assert
+//     (reinterpret_cast<uintptr_t>(g) % 16 == reinterpret_cast<uintptr_t>(b) %
+//     16);
 
 //     size_t i = start;
 //     while (true) {
 //         if (i >= end) {
-//             // If we get to the end before getting to an aligned address, just return.
+//             // If we get to the end before getting to an aligned address,
+//             just return.
 //             // (Or, for non-SSE mode, if we get to the end.)
 //             return;
 // #ifdef __SSE2__
 //         } else if (reinterpret_cast<uintptr_t>(&r[i]) % 16 == 0) {
-//             // Otherwise, we get to the first aligned address; go to the SSE part.
-//             break;
+//             // Otherwise, we get to the first aligned address; go to the SSE
+//             part. break;
 // #endif
 //         }
 //         Apply(r[i], g[i], b[i]);
@@ -611,12 +620,10 @@ inline void WeightedStdToneCurve::Apply (float& ir, float& ig, float& ib) const
 //         vfloat r_old = LVF(r[i]);
 //         vfloat g_old = LVF(g[i]);
 //         vfloat b_old = LVF(b[i]);
-//         vfloat r_new = vclampf(r1 * zd5v + r2 * zd25v + r3 * zd25v, ZEROV, c65535v);
-//         vfloat g_new = vclampf(g1 * zd25v + g2 * zd5v + g3 * zd25v, ZEROV, c65535v);
-//         vfloat b_new = vclampf(b1 * zd25v + b2 * zd25v + b3 * zd5v, ZEROV, c65535v);
-//         r_old = r_new;
-//         g_old = g_new;
-//         b_old = b_new;
+//         vfloat r_new = vclampf(r1 * zd5v + r2 * zd25v + r3 * zd25v, ZEROV,
+//         c65535v); vfloat g_new = vclampf(g1 * zd25v + g2 * zd5v + g3 * zd25v,
+//         ZEROV, c65535v); vfloat b_new = vclampf(b1 * zd25v + b2 * zd25v + b3
+//         * zd5v, ZEROV, c65535v); r_old = r_new; g_old = g_new; b_old = b_new;
 //         STVF(r[i], r_old);
 //         STVF(g[i], g_old);
 //         STVF(b[i], b_old);
@@ -631,10 +638,11 @@ inline void WeightedStdToneCurve::Apply (float& ir, float& ig, float& ib) const
 
 // Tone curve modifying the value channel only, preserving hue and saturation
 // values in 0xffff space
-inline void SatAndValueBlendingToneCurve::Apply (float& ir, float& ig, float& ib) const
+inline void SatAndValueBlendingToneCurve::Apply(float &ir, float &ig,
+                                                float &ib) const
 {
 
-    assert (lutToneCurve);
+    assert(lutToneCurve);
 
     float r = CLIP(ir);
     float g = CLIP(ig);
@@ -658,7 +666,7 @@ inline void SatAndValueBlendingToneCurve::Apply (float& ir, float& ig, float& ib
         s *= 1.f - coef;
     } else {
         // Linearly targeting Value = 0
-        const float coef = (newLum - lum) / lum ;
+        const float coef = (newLum - lum) / lum;
         dV = v * coef;
     }
     Color::hsv2rgbdcp(h, s, v + dV, r, g, b);
@@ -671,4 +679,3 @@ inline void SatAndValueBlendingToneCurve::Apply (float& ir, float& ig, float& ib
 } // namespace rtengine
 
 #undef CLIPI
-
