@@ -26,8 +26,7 @@
 namespace {
 
 // "ceil" rounding
-template<typename T>
-constexpr T skips(T a, T b)
+template <typename T> constexpr T skips(T a, T b)
 {
     return a / b + static_cast<bool>(a % b);
 }
@@ -36,18 +35,16 @@ constexpr T skips(T a, T b)
 
 namespace rtengine {
 
-extern const Settings* settings;
+extern const Settings *settings;
 
-Crop::Crop(ImProcCoordinator* parent, EditDataProvider *editDataProvider, bool isDetailWindow)
+Crop::Crop(ImProcCoordinator *parent, EditDataProvider *editDataProvider,
+           bool isDetailWindow)
     : PipetteBuffer(editDataProvider), origCrop(nullptr), spotCrop(nullptr),
-      denoiseCrop(nullptr),
-      cropImg (nullptr), transCrop (nullptr), 
-      updating(false), newUpdatePending(false), skip(10),
-      cropx(0), cropy(0), cropw(-1), croph(-1),
-      trafx(0), trafy(0), trafw(-1), trafh(-1),
-      rqcropx(0), rqcropy(0), rqcropw(-1), rqcroph(-1),
-      borderRequested(32), upperBorder(0), leftBorder(0),
-      cropAllocated(false),
+      denoiseCrop(nullptr), cropImg(nullptr), transCrop(nullptr),
+      updating(false), newUpdatePending(false), skip(10), cropx(0), cropy(0),
+      cropw(-1), croph(-1), trafx(0), trafy(0), trafw(-1), trafh(-1),
+      rqcropx(0), rqcropy(0), rqcropw(-1), rqcroph(-1), borderRequested(32),
+      upperBorder(0), leftBorder(0), cropAllocated(false),
       cropImageListener(nullptr), parent(parent), isDetailWindow(isDetailWindow)
 {
     for (int i = 0; i < 3; ++i) {
@@ -64,7 +61,8 @@ Crop::~Crop()
 
     MyMutex::MyLock cropLock(cropMutex);
 
-    std::vector<Crop*>::iterator i = std::find(parent->crops.begin(), parent->crops.end(), this);
+    std::vector<Crop *>::iterator i =
+        std::find(parent->crops.begin(), parent->crops.end(), this);
 
     if (i != parent->crops.end()) {
         parent->crops.erase(i);
@@ -81,9 +79,10 @@ Crop::~Crop()
 //     freeAll();
 // }
 
-void Crop::setListener(DetailedCropListener* il)
+void Crop::setListener(DetailedCropListener *il)
 {
-    // We can make reads in the IF, because the mProcessing lock is only needed for change
+    // We can make reads in the IF, because the mProcessing lock is only needed
+    // for change
     if (cropImageListener != il) {
         MyMutex::MyLock lock(cropMutex);
         cropImageListener = il;
@@ -92,7 +91,10 @@ void Crop::setListener(DetailedCropListener* il)
 
 EditUniqueID Crop::getCurrEditID()
 {
-    EditSubscriber *subscriber = PipetteBuffer::dataProvider ? PipetteBuffer::dataProvider->getCurrSubscriber() : nullptr;
+    EditSubscriber *subscriber =
+        PipetteBuffer::dataProvider
+            ? PipetteBuffer::dataProvider->getCurrSubscriber()
+            : nullptr;
     return subscriber ? subscriber->getEditID() : EUID_None;
 }
 
@@ -100,14 +102,21 @@ EditUniqueID Crop::getCurrEditID()
  * Delete the edit image buffer if there's no subscriber anymore.
  * If allocation has to be done, it is deferred to Crop::update
  */
-void Crop::setEditSubscriber(EditSubscriber* newSubscriber)
+void Crop::setEditSubscriber(EditSubscriber *newSubscriber)
 {
     MyMutex::MyLock lock(cropMutex);
 
-    // At this point, editCrop.dataProvider->currSubscriber is the old subscriber
-    EditSubscriber *oldSubscriber = PipetteBuffer::dataProvider ? PipetteBuffer::dataProvider->getCurrSubscriber() : nullptr;
+    // At this point, editCrop.dataProvider->currSubscriber is the old
+    // subscriber
+    EditSubscriber *oldSubscriber =
+        PipetteBuffer::dataProvider
+            ? PipetteBuffer::dataProvider->getCurrSubscriber()
+            : nullptr;
 
-    if (newSubscriber == nullptr || (oldSubscriber != nullptr && oldSubscriber->getPipetteBufferType() != newSubscriber->getPipetteBufferType())) {
+    if (newSubscriber == nullptr ||
+        (oldSubscriber != nullptr &&
+         oldSubscriber->getPipetteBufferType() !=
+             newSubscriber->getPipetteBufferType())) {
         if (PipetteBuffer::imgFloatBuffer != nullptr) {
             delete PipetteBuffer::imgFloatBuffer;
             PipetteBuffer::imgFloatBuffer = nullptr;
@@ -123,7 +132,9 @@ void Crop::setEditSubscriber(EditSubscriber* newSubscriber)
         }
     }
 
-    // If oldSubscriber == NULL && newSubscriber != NULL && newSubscriber->getEditingType() == ET_PIPETTE-> the image will be allocated when necessary
+    // If oldSubscriber == NULL && newSubscriber != NULL &&
+    // newSubscriber->getEditingType() == ET_PIPETTE-> the image will be
+    // allocated when necessary
 }
 
 bool Crop::hasListener()
@@ -136,13 +147,15 @@ void Crop::update(int todo)
 {
     MyMutex::MyLock cropLock(cropMutex);
 
-    ProcParams& params = parent->params;
-//       CropGUIListener* cropgl;
+    ProcParams &params = parent->params;
+    //       CropGUIListener* cropgl;
 
-    // No need to update todo here, since it has already been changed in ImprocCoordinator::updatePreviewImage,
-    // and Crop::update ask to do ALL anyway
+    // No need to update todo here, since it has already been changed in
+    // ImprocCoordinator::updatePreviewImage, and Crop::update ask to do ALL
+    // anyway
 
-    // give possibility to the listener to modify crop window (as the full image dimensions are already known at this point)
+    // give possibility to the listener to modify crop window (as the full image
+    // dimensions are already known at this point)
     int wx, wy, ww, wh, ws;
     const bool overrideWindow = cropImageListener;
     bool spotsDone = false;
@@ -155,44 +168,51 @@ void Crop::update(int todo)
     bool needsinitupdate = false;
 
     if (!overrideWindow) {
-        needsinitupdate = setCropSizes(rqcropx, rqcropy, rqcropw, rqcroph, skip, true);
+        needsinitupdate =
+            setCropSizes(rqcropx, rqcropy, rqcropw, rqcroph, skip, true);
     } else {
-        needsinitupdate = setCropSizes(wx, wy, ww, wh, ws, true);     // this set skip=ws
+        needsinitupdate =
+            setCropSizes(wx, wy, ww, wh, ws, true); // this set skip=ws
     }
 
-    // it something has been reallocated, all processing steps have to be performed
+    // it something has been reallocated, all processing steps have to be
+    // performed
     if (needsinitupdate || (todo & M_HIGHQUAL)) {
         todo = ALL;
     }
 
-    // Tells to the ImProcFunctions' tool what is the preview scale, which may lead to some simplifications
+    // Tells to the ImProcFunctions' tool what is the preview scale, which may
+    // lead to some simplifications
     parent->ipf.setScale(skip);
     parent->ipf.setPipetteBuffer(this);
     parent->ipf.setViewport(0, 0, -1, -1);
     parent->ipf.setOutputHistograms(nullptr, nullptr, nullptr);
     parent->ipf.setShowSharpeningMask(parent->sharpMask);
 
-    Imagefloat* baseCrop = origCrop;
+    Imagefloat *baseCrop = origCrop;
 
-    bool needstransform  = parent->ipf.needsTransform();
-    bool show_denoise = params.denoise.enabled && (skip == 1 || options.denoiseZoomedOut);
+    bool needstransform = parent->ipf.needsTransform();
+    bool show_denoise =
+        params.denoise.enabled && (skip == 1 || options.denoiseZoomedOut);
 
-    const auto invert_negative =
-        [&](Imagefloat *img) -> bool
-        {
-            bool converted = false;
-            if (params.filmNegative.enabled) {
-                if (params.filmNegative.colorSpace == FilmNegativeParams::ColorSpace::WORKING) {
-                    converted = true;
-                    parent->imgsrc->convertColorSpace(img, params.icm, parent->currWB);
-                } 
-                parent->ipf.filmNegativeProcess(img, img, params.filmNegative, params.raw, parent->imgsrc, parent->currWB);
+    const auto invert_negative = [&](Imagefloat *img) -> bool {
+        bool converted = false;
+        if (params.filmNegative.enabled) {
+            if (params.filmNegative.colorSpace ==
+                FilmNegativeParams::ColorSpace::WORKING) {
+                converted = true;
+                parent->imgsrc->convertColorSpace(img, params.icm,
+                                                  parent->currWB);
             }
-            return converted;
-        };
+            parent->ipf.filmNegativeProcess(img, img, params.filmNegative,
+                                            params.raw, parent->imgsrc,
+                                            parent->currWB);
+        }
+        return converted;
+    };
 
     if (todo & M_INIT) {
-        MyMutex::MyLock lock(parent->minit);  // Also used in improccoord
+        MyMutex::MyLock lock(parent->minit); // Also used in improccoord
 
         int tr = getCoarseBitMask(params.coarse);
 
@@ -201,41 +221,56 @@ void Crop::update(int todo)
         }
 
         PreviewProps pp(trafx, trafy, trafw * skip, trafh * skip, skip);
-        parent->imgsrc->getImage(parent->currWB, tr, origCrop, pp, params.exposure, params.raw);
-        
+        parent->imgsrc->getImage(parent->currWB, tr, origCrop, pp,
+                                 params.exposure, params.raw);
+
         if (!invert_negative(origCrop)) {
-            parent->imgsrc->convertColorSpace(origCrop, params.icm, parent->currWB);
+            parent->imgsrc->convertColorSpace(origCrop, params.icm,
+                                              parent->currWB);
         }
     }
 
     Imagefloat *hdr_base_crop = origCrop;
-    
+
     if (todo & M_LINDENOISE) {
         if (!denoiseCrop) {
-            denoiseCrop = new Imagefloat(origCrop->getWidth(), origCrop->getHeight());
+            denoiseCrop =
+                new Imagefloat(origCrop->getWidth(), origCrop->getHeight());
         }
         origCrop->copyTo(denoiseCrop);
         hdr_base_crop = denoiseCrop;
         baseCrop = denoiseCrop;
-        
+
         if (show_denoise) {
-            parent->ipf.denoiseComputeParams(parent->imgsrc, parent->currWB, parent->denoiseInfoStore, params.denoise);
+            parent->ipf.denoiseComputeParams(parent->imgsrc, parent->currWB,
+                                             parent->denoiseInfoStore,
+                                             params.denoise);
 
             if ((!isDetailWindow) && parent->adnListener) {
-                parent->adnListener->chromaChanged(params.denoise.chrominance, params.denoise.chrominanceRedGreen, params.denoise.chrominanceBlueYellow);
+                parent->adnListener->chromaChanged(
+                    params.denoise.chrominance,
+                    params.denoise.chrominanceRedGreen,
+                    params.denoise.chrominanceBlueYellow);
             }
 
-            parent->ipf.denoise(parent->imgsrc, parent->currWB, denoiseCrop, parent->denoiseInfoStore, params.denoise);
+            parent->ipf.denoise(parent->imgsrc, parent->currWB, denoiseCrop,
+                                parent->denoiseInfoStore, params.denoise);
 
-            if (parent->adnListener && params.denoise.chrominanceMethod == DenoiseParams::ChrominanceMethod::AUTOMATIC) {
-                parent->adnListener->chromaChanged(params.denoise.chrominance, params.denoise.chrominanceRedGreen, params.denoise.chrominanceBlueYellow);
+            if (parent->adnListener &&
+                params.denoise.chrominanceMethod ==
+                    DenoiseParams::ChrominanceMethod::AUTOMATIC) {
+                parent->adnListener->chromaChanged(
+                    params.denoise.chrominance,
+                    params.denoise.chrominanceRedGreen,
+                    params.denoise.chrominanceBlueYellow);
             }
         }
     } else if (denoiseCrop) {
         baseCrop = denoiseCrop;
     }
 
-    // has to be called after setCropSizes! Tools prior to this point can't handle the Edit mechanism, but that shouldn't be a problem.
+    // has to be called after setCropSizes! Tools prior to this point can't
+    // handle the Edit mechanism, but that shouldn't be a problem.
     createBuffer(cropw, croph);
 
     int offset_x = cropx / skip;
@@ -254,7 +289,9 @@ void Crop::update(int todo)
             if (!params.spot.entries.empty()) {
                 PreviewProps pp(trafx, trafy, trafw * skip, trafh * skip, skip);
                 int tr = getCoarseBitMask(params.coarse);
-                parent->ipf.removeSpots(spotCrop, parent->imgsrc, params.spot.entries, pp, parent->currWB, &params.icm, tr, &parent->denoiseInfoStore);
+                parent->ipf.removeSpots(
+                    spotCrop, parent->imgsrc, params.spot.entries, pp,
+                    parent->currWB, &params.icm, tr, &parent->denoiseInfoStore);
             }
         } else {
             if (spotCrop) {
@@ -281,11 +318,13 @@ void Crop::update(int todo)
 
         if (trafx || trafy || trafw != fw || trafh != fh) {
             need_cropping = true;
-            const bool copy_from_earlier_steps = params.denoise.enabled || params.spot.enabled;
+            const bool copy_from_earlier_steps =
+                params.denoise.enabled || params.spot.enabled;
 
             // fattal needs to work on the full image. So here we get the full
             // image from imgsrc, and replace the denoised crop in case
-            if (!copy_from_earlier_steps && skip == 1 && parent->drcomp_11_dcrop_cache) {
+            if (!copy_from_earlier_steps && skip == 1 &&
+                parent->drcomp_11_dcrop_cache) {
                 f = parent->drcomp_11_dcrop_cache;
                 need_drcomp = false;
                 pipeline_stop_[0] = parent->pipeline_stop_[0];
@@ -294,9 +333,11 @@ void Crop::update(int todo)
                 drCompCrop.reset(f);
                 PreviewProps pp(0, 0, parent->fw, parent->fh, skip);
                 int tr = getCoarseBitMask(params.coarse);
-                parent->imgsrc->getImage(parent->currWB, tr, f, pp, params.exposure, params.raw);
+                parent->imgsrc->getImage(parent->currWB, tr, f, pp,
+                                         params.exposure, params.raw);
                 if (!invert_negative(f)) {
-                    parent->imgsrc->convertColorSpace(f, params.icm, parent->currWB);
+                    parent->imgsrc->convertColorSpace(f, params.icm,
+                                                      parent->currWB);
                 }
 
                 if (copy_from_earlier_steps) {
@@ -304,7 +345,7 @@ void Crop::update(int todo)
                     int oy = trafy / skip;
                     int ox = trafx / skip;
 #ifdef _OPENMP
-                    #pragma omp parallel for
+#pragma omp parallel for
 #endif
 
                     for (int y = 0; y < baseCrop->getHeight(); ++y) {
@@ -325,7 +366,9 @@ void Crop::update(int todo)
         }
 
         if (need_drcomp) {
-            pipeline_stop_[0] = parent->ipf.process(ImProcFunctions::Pipeline::PREVIEW, ImProcFunctions::Stage::STAGE_0, f);
+            pipeline_stop_[0] =
+                parent->ipf.process(ImProcFunctions::Pipeline::PREVIEW,
+                                    ImProcFunctions::Stage::STAGE_0, f);
         }
         stop = pipeline_stop_[0];
 
@@ -335,7 +378,7 @@ void Crop::update(int todo)
             int oy = trafy / skip;
             int ox = trafx / skip;
 #ifdef _OPENMP
-#           pragma omp parallel for
+#pragma omp parallel for
 #endif
             for (int y = 0; y < trafh; ++y) {
                 int cy = y + oy;
@@ -359,9 +402,12 @@ void Crop::update(int todo)
         }
 
         if (needstransform) {
-            parent->ipf.transform(baseCrop, transCrop, cropx / skip, cropy / skip, trafx / skip, trafy / skip, skips(parent->fw, skip), skips(parent->fh, skip), parent->getFullWidth(), parent->getFullHeight(),
-                                  parent->imgsrc->getMetaData(),
-                                  parent->imgsrc->getRotateDegree(), false);
+            parent->ipf.transform(
+                baseCrop, transCrop, cropx / skip, cropy / skip, trafx / skip,
+                trafy / skip, skips(parent->fw, skip), skips(parent->fh, skip),
+                parent->getFullWidth(), parent->getFullHeight(),
+                parent->imgsrc->getMetaData(),
+                parent->imgsrc->getRotateDegree(), false);
         } else {
             baseCrop->copyTo(transCrop);
         }
@@ -380,8 +426,11 @@ void Crop::update(int todo)
     if (todo & M_RGBCURVE) {
         Imagefloat *workingCrop = baseCrop;
         workingCrop->copyTo(bufs_[0]);
-        pipeline_stop_[1] = stop || parent->ipf.process(ImProcFunctions::Pipeline::PREVIEW, ImProcFunctions::Stage::STAGE_1, bufs_[0]);
-        
+        pipeline_stop_[1] =
+            stop ||
+            parent->ipf.process(ImProcFunctions::Pipeline::PREVIEW,
+                                ImProcFunctions::Stage::STAGE_1, bufs_[0]);
+
         if (workingCrop != baseCrop) {
             delete workingCrop;
         }
@@ -390,15 +439,21 @@ void Crop::update(int todo)
 
     if (todo & M_LUMACURVE) {
         bufs_[0]->copyTo(bufs_[1]);
-        
-        pipeline_stop_[2] = stop || parent->ipf.process(ImProcFunctions::Pipeline::PREVIEW, ImProcFunctions::Stage::STAGE_2, bufs_[1]);
+
+        pipeline_stop_[2] =
+            stop ||
+            parent->ipf.process(ImProcFunctions::Pipeline::PREVIEW,
+                                ImProcFunctions::Stage::STAGE_2, bufs_[1]);
     }
     stop = stop || pipeline_stop_[2];
-    
+
     if (todo & (M_LUMINANCE | M_COLOR)) {
         bufs_[1]->copyTo(bufs_[2]);
 
-        pipeline_stop_[3] = stop || parent->ipf.process(ImProcFunctions::Pipeline::PREVIEW, ImProcFunctions::Stage::STAGE_3, bufs_[2]);
+        pipeline_stop_[3] =
+            stop ||
+            parent->ipf.process(ImProcFunctions::Pipeline::PREVIEW,
+                                ImProcFunctions::Stage::STAGE_3, bufs_[2]);
     }
     stop = stop || pipeline_stop_[3];
 
@@ -409,7 +464,9 @@ void Crop::update(int todo)
 
     if (cropImageListener) {
         // internal image in output color space for analysis
-        Image8 *cropImgtrue = parent->ipf.rgb2out(bufs_[2], 0, 0, cropImg->getWidth(), cropImg->getHeight(), params.icm);
+        Image8 *cropImgtrue =
+            parent->ipf.rgb2out(bufs_[2], 0, 0, cropImg->getWidth(),
+                                cropImg->getHeight(), params.icm);
 
         int finalW = rqcropw;
 
@@ -423,35 +480,41 @@ void Crop::update(int todo)
             finalH = cropImg->getHeight() - upperBorder;
         }
 
-        Image8* final = new Image8(finalW, finalH);
-        Image8* finaltrue = new Image8(finalW, finalH);
+        Image8 *final = new Image8(finalW, finalH);
+        Image8 *finaltrue = new Image8(finalW, finalH);
 
         const int cW = cropImg->getWidth();
 
         for (int i = 0; i < finalH; i++) {
-            memcpy(final->data + 3 * i * finalW, cropImg->data + 3 * (i + upperBorder)*cW + 3 * leftBorder, 3 * finalW);
-            memcpy(finaltrue->data + 3 * i * finalW, cropImgtrue->data + 3 * (i + upperBorder)*cW + 3 * leftBorder, 3 * finalW);
+            memcpy(final->data + 3 * i * finalW,
+                   cropImg->data + 3 * (i + upperBorder) * cW + 3 * leftBorder,
+                   3 * finalW);
+            memcpy(finaltrue->data + 3 * i * finalW,
+                   cropImgtrue->data + 3 * (i + upperBorder) * cW +
+                       3 * leftBorder,
+                   3 * finalW);
         }
 
-        cropImageListener->setDetailedCrop(final, finaltrue, params.icm, params.crop, rqcropx, rqcropy, rqcropw, rqcroph, skip);
+        cropImageListener->setDetailedCrop(final, finaltrue, params.icm,
+                                           params.crop, rqcropx, rqcropy,
+                                           rqcropw, rqcroph, skip);
         delete final;
         delete finaltrue;
         delete cropImgtrue;
     }
 }
 
-
 void Crop::freeAll()
 {
 
     if (cropAllocated) {
         if (origCrop) {
-            delete    origCrop;
+            delete origCrop;
             origCrop = nullptr;
         }
 
         if (transCrop) {
-            delete    transCrop;
+            delete transCrop;
             transCrop = nullptr;
         }
 
@@ -466,14 +529,14 @@ void Crop::freeAll()
         }
 
         for (int i = 3; i > 0; --i) {
-            if (bufs_[i-1]) {
-                delete bufs_[i-1];
-                bufs_[i-1] = nullptr;
+            if (bufs_[i - 1]) {
+                delete bufs_[i - 1];
+                bufs_[i - 1] = nullptr;
             }
         }
 
         if (cropImg) {
-            delete    cropImg;
+            delete cropImg;
             cropImg = nullptr;
         }
 
@@ -483,10 +546,11 @@ void Crop::freeAll()
     cropAllocated = false;
 }
 
-
 namespace {
 
-bool check_need_larger_crop_for_transform(int fw, int fh, int x, int y, int w, int h, const ProcParams &params, double &adjust)
+bool check_need_larger_crop_for_transform(int fw, int fh, int x, int y, int w,
+                                          int h, const ProcParams &params,
+                                          double &adjust)
 {
     if (x == 0 && y == 0 && w == fw && h == fh) {
         return false;
@@ -505,11 +569,13 @@ bool check_need_larger_crop_for_transform(int fw, int fh, int x, int y, int w, i
 
 } // namespace
 
-/** @brief Handles crop's image buffer reallocation and trigger sizeChanged of SizeListener[s]
- * If the scale changes, this method will free all buffers and reallocate ones of the new size.
- * It will then tell to the SizeListener that size has changed (sizeChanged)
+/** @brief Handles crop's image buffer reallocation and trigger sizeChanged of
+ * SizeListener[s] If the scale changes, this method will free all buffers and
+ * reallocate ones of the new size. It will then tell to the SizeListener that
+ * size has changed (sizeChanged)
  */
-bool Crop::setCropSizes(int rcx, int rcy, int rcw, int rch, int skip, bool internal)
+bool Crop::setCropSizes(int rcx, int rcy, int rcw, int rch, int skip,
+                        bool internal)
 {
 
     if (!internal) {
@@ -546,20 +612,27 @@ bool Crop::setCropSizes(int rcx, int rcy, int rcw, int rch, int skip, bool inter
     int bw = bx2 - bx1 + 1;
     int bh = by2 - by1 + 1;
 
-    // determine which part of the source image is required to compute the crop rectangle
+    // determine which part of the source image is required to compute the crop
+    // rectangle
     int orx, ory, orw, orh;
     orx = bx1;
     ory = by1;
     orw = bw;
     orh = bh;
 
-    parent->ipf.transCoord(parent->fw, parent->fh, bx1, by1, bw, bh, orx, ory, orw, orh);
+    parent->ipf.transCoord(parent->fw, parent->fh, bx1, by1, bw, bh, orx, ory,
+                           orw, orh);
 
     double adjust = 0.f;
-    if (check_need_larger_crop_for_transform(parent->fw, parent->fh, orx, ory, orw, orh, parent->params, adjust)) {
-        // TODO - "adjust" is an estimate of the max distortion relative to the image size. It is hardcoded to be 15% for lens distortion correction, and 100% for perspective (because we don't know better yet -- ideally this should be calculated)
-        int dW = int (double (parent->fw) * adjust / 2);//(2 * skip));
-        int dH = int (double (parent->fh) * adjust / 2);//(2 * skip));
+    if (check_need_larger_crop_for_transform(parent->fw, parent->fh, orx, ory,
+                                             orw, orh, parent->params,
+                                             adjust)) {
+        // TODO - "adjust" is an estimate of the max distortion relative to the
+        // image size. It is hardcoded to be 15% for lens distortion correction,
+        // and 100% for perspective (because we don't know better yet -- ideally
+        // this should be calculated)
+        int dW = int(double(parent->fw) * adjust / 2); //(2 * skip));
+        int dH = int(double(parent->fh) * adjust / 2); //(2 * skip));
         int x1 = orx - dW;
         int x2 = orx + orw + dW;
         int y1 = ory - dH;
@@ -591,7 +664,7 @@ bool Crop::setCropSizes(int rcx, int rcy, int rcw, int rch, int skip, bool inter
         orh = min(y2 - y1, parent->fh - ory);
     }
 
-    leftBorder  = skips(rqx1 - bx1, skip);
+    leftBorder = skips(rqx1 - bx1, skip);
     upperBorder = skips(rqy1 - by1, skip);
 
     PreviewProps cp(orx, ory, orw, orh, skip);
@@ -622,7 +695,7 @@ bool Crop::setCropSizes(int rcx, int rcy, int rcw, int rch, int skip, bool inter
         if (!origCrop) {
             origCrop = new Imagefloat();
         }
-        origCrop->allocate(trafw, trafh);  // Resizing the buffer (optimization)
+        origCrop->allocate(trafw, trafh); // Resizing the buffer (optimization)
 
         // if transCrop doesn't exist yet, it'll be created where necessary
         if (transCrop) {
@@ -643,7 +716,7 @@ bool Crop::setCropSizes(int rcx, int rcy, int rcw, int rch, int skip, bool inter
         if (!cropImg) {
             cropImg = new Image8();
         }
-        cropImg->allocate(cropw, croph);  // Resizing the buffer (optimization)
+        cropImg->allocate(cropw, croph); // Resizing the buffer (optimization)
 
         if (editType == ET_PIPETTE) {
             PipetteBuffer::resize(cropw, croph);
@@ -666,7 +739,7 @@ bool Crop::setCropSizes(int rcx, int rcy, int rcw, int rch, int skip, bool inter
     for (int i = 0; i < 3; ++i) {
         bufs_[i]->assignColorSpace(parent->params.icm.workingProfile);
     }
-    
+
     cropx = bx1;
     cropy = by1;
 
@@ -678,9 +751,10 @@ bool Crop::setCropSizes(int rcx, int rcy, int rcw, int rch, int skip, bool inter
 }
 
 /** @brief Look out if a new thread has to be started to process the update
-  *
-  * @return If true, a new updating thread has to be created. If false, the current updating thread will be used
-  */
+ *
+ * @return If true, a new updating thread has to be created. If false, the
+ * current updating thread will be used
+ */
 bool Crop::tryUpdate()
 {
     bool needsNewThread = true;
@@ -700,10 +774,12 @@ bool Crop::tryUpdate()
 
 /* @brief Handles Crop updating in its own thread
  *
- * This method will cycle updates as long as Crop::newUpdatePending will be true. During the processing,
- * intermediary update will be automatically flushed by Crop::tryUpdate.
+ * This method will cycle updates as long as Crop::newUpdatePending will be
+ * true. During the processing, intermediary update will be automatically
+ * flushed by Crop::tryUpdate.
  *
- * This method is called when the visible part of the crop has changed (resize, zoom, etc..), so it needs a full update
+ * This method is called when the visible part of the crop has changed (resize,
+ * zoom, etc..), so it needs a full update
  */
 void Crop::fullUpdate()
 {
@@ -713,7 +789,8 @@ void Crop::fullUpdate()
     // parent->wait_not_running();
     // parent->set_updater_running(true);
     // if (parent->updaterRunning && parent->thread) {
-    //     // Do NOT reset changes here, since in a long chain of events it will lead to chroma_scale not being updated,
+    //     // Do NOT reset changes here, since in a long chain of events it will
+    //     lead to chroma_scale not being updated,
     //     // causing Color::lab2rgb to return a black image on some opens
     //     //parent->changeSinceLast = 0;
     //     parent->thread->join();
@@ -739,7 +816,7 @@ void Crop::fullUpdate()
         parent->restoreParams();
     }
 
-    updating = false;  // end of crop update
+    updating = false; // end of crop update
 
     if (parent->plistener) {
         parent->plistener->setProgressState(false);
@@ -767,4 +844,4 @@ int Crop::getUpperBorder()
     return upperBorder;
 }
 
-}
+} // namespace rtengine
