@@ -19,35 +19,35 @@
  *  Class created by Jean-Christophe FRISCH, aka 'Hombre'
  */
 
-#include "curveeditor.h"
 #include "curveeditorgroup.h"
+#include "curveeditor.h"
 #include "diagonalcurveeditorsubgroup.h"
 #include "flatcurveeditorsubgroup.h"
 #include "multilangmgr.h"
 #include "rtimage.h"
 
-
-CurveEditorGroup::CurveEditorGroup(Glib::ustring& curveDir, Glib::ustring groupLabel, float curvesRatio):
-    curveDir(curveDir),
-    curve_reset(nullptr),
-    displayedCurve(nullptr),
-    flatSubGroup(nullptr),
-    diagonalSubGroup(nullptr),
-    cl(nullptr),
-    numberOfPackedCurve(0),
-    curvesRatio(curvesRatio)
+CurveEditorGroup::CurveEditorGroup(Glib::ustring &curveDir,
+                                   Glib::ustring groupLabel, float curvesRatio)
+    : curveDir(curveDir), curve_reset(nullptr), displayedCurve(nullptr),
+      flatSubGroup(nullptr), diagonalSubGroup(nullptr), cl(nullptr),
+      numberOfPackedCurve(0), curvesRatio(curvesRatio)
 {
 
-    // We set the label to the one provided as parameter, even if it's an empty string
-    curveGroupLabel = Gtk::manage (new Gtk::Label (groupLabel.empty() ? groupLabel : (groupLabel + ": "), Gtk::ALIGN_START));
-    setExpandAlignProperties(curveGroupLabel, false, false, Gtk::ALIGN_START, Gtk::ALIGN_CENTER);
-    //set_row_spacing(RTScalable::getScale());
+    // We set the label to the one provided as parameter, even if it's an empty
+    // string
+    curveGroupLabel = Gtk::manage(
+        new Gtk::Label(groupLabel.empty() ? groupLabel : (groupLabel + ": "),
+                       Gtk::ALIGN_START));
+    setExpandAlignProperties(curveGroupLabel, false, false, Gtk::ALIGN_START,
+                             Gtk::ALIGN_CENTER);
+    // set_row_spacing(RTScalable::getScale());
     set_spacing(RTScalable::getScale());
 }
 
 CurveEditorGroup::~CurveEditorGroup()
 {
-    for (std::vector<CurveEditor*>::iterator i = curveEditors.begin(); i != curveEditors.end(); ++i) {
+    for (std::vector<CurveEditor *>::iterator i = curveEditors.begin();
+         i != curveEditors.end(); ++i) {
         delete *i;
     }
 
@@ -76,24 +76,29 @@ void CurveEditorGroup::hideCurrentCurve()
  *
  * Parameters:
  *     cType:         enum saying which kind of curve type has to be created
- *     curveLabel:    Name of the curve that will be inserted in the toggle button, before the image.
- *                    If empty, no text will prepend the image
- *     relatedWidget: pointer to a widget (or NULL) that will be inserted next to the curve's toggle button.
- *                    if a smart pointer created by Gtk::manage is passed in, the widget will be deleted by the destructor,
- *                    otherwise it'll have to be delete it manually
- *     periodic:      for FlatCurve only, ask the curve to be periodic (default: True)
+ *     curveLabel:    Name of the curve that will be inserted in the toggle
+ * button, before the image. If empty, no text will prepend the image
+ *     relatedWidget: pointer to a widget (or NULL) that will be inserted next
+ * to the curve's toggle button. if a smart pointer created by Gtk::manage is
+ * passed in, the widget will be deleted by the destructor, otherwise it'll have
+ * to be delete it manually periodic:      for FlatCurve only, ask the curve to
+ * be periodic (default: True)
  *
  */
-CurveEditor* CurveEditorGroup::addCurve(CurveType cType, Glib::ustring curveLabel, Gtk::Widget *relatedWidget, bool expandRelatedWidget, bool periodic)
+CurveEditor *CurveEditorGroup::addCurve(CurveType cType,
+                                        Glib::ustring curveLabel,
+                                        Gtk::Widget *relatedWidget,
+                                        bool expandRelatedWidget, bool periodic)
 {
     switch (cType) {
     case (CT_Diagonal): {
         if (!diagonalSubGroup) {
-            diagonalSubGroup = new DiagonalCurveEditorSubGroup(this, curveDir, curvesRatio);
+            diagonalSubGroup =
+                new DiagonalCurveEditorSubGroup(this, curveDir, curvesRatio);
         }
 
         // We add it to the curve editor list
-        DiagonalCurveEditor* newCE = diagonalSubGroup->addCurve(curveLabel);
+        DiagonalCurveEditor *newCE = diagonalSubGroup->addCurve(curveLabel);
         newCE->relatedWidget = relatedWidget;
         newCE->expandRelatedWidget = expandRelatedWidget;
         curveEditors.push_back(newCE);
@@ -102,11 +107,12 @@ CurveEditor* CurveEditorGroup::addCurve(CurveType cType, Glib::ustring curveLabe
 
     case (CT_Flat): {
         if (!flatSubGroup) {
-            flatSubGroup = new FlatCurveEditorSubGroup(this, curveDir, curvesRatio);
+            flatSubGroup =
+                new FlatCurveEditorSubGroup(this, curveDir, curvesRatio);
         }
 
         // We add it to the curve editor list
-        FlatCurveEditor* newCE = flatSubGroup->addCurve(curveLabel, periodic);
+        FlatCurveEditor *newCE = flatSubGroup->addCurve(curveLabel, periodic);
         newCE->relatedWidget = relatedWidget;
         newCE->expandRelatedWidget = expandRelatedWidget;
         curveEditors.push_back(newCE);
@@ -114,7 +120,7 @@ CurveEditor* CurveEditorGroup::addCurve(CurveType cType, Glib::ustring curveLabe
     }
 
     default:
-        return (static_cast<CurveEditor*>(nullptr));
+        return (static_cast<CurveEditor *>(nullptr));
         break;
     }
 
@@ -128,8 +134,9 @@ void CurveEditorGroup::newLine()
 {
 
     if (curveEditors.size() > numberOfPackedCurve) {
-        Gtk::Grid* currLine = Gtk::manage (new Gtk::Grid ());
-        setExpandAlignProperties(currLine, true, false, Gtk::ALIGN_FILL, Gtk::ALIGN_START);
+        Gtk::Grid *currLine = Gtk::manage(new Gtk::Grid());
+        setExpandAlignProperties(currLine, true, false, Gtk::ALIGN_FILL,
+                                 Gtk::ALIGN_START);
         currLine->set_column_spacing(RTScalable::getScale());
 
         bool isHeader = false;
@@ -143,25 +150,35 @@ void CurveEditorGroup::newLine()
         bool rwe = false;
 
         for (int i = numberOfPackedCurve; i < (int)(curveEditors.size()); ++i) {
-            if (curveEditors[i]->relatedWidget != nullptr && curveEditors[i]->expandRelatedWidget) {
+            if (curveEditors[i]->relatedWidget != nullptr &&
+                curveEditors[i]->expandRelatedWidget) {
                 rwe = true;
             }
         }
 
         for (int i = numberOfPackedCurve; i < (int)(curveEditors.size()); ++i) {
-            setExpandAlignProperties(curveEditors[i]->curveType->buttonGroup, !rwe, true, Gtk::ALIGN_FILL, Gtk::ALIGN_FILL);
+            setExpandAlignProperties(curveEditors[i]->curveType->buttonGroup,
+                                     !rwe, true, Gtk::ALIGN_FILL,
+                                     Gtk::ALIGN_FILL);
             // if (curveEditors[i]->relatedWidget != nullptr) {
             //     Gtk::HBox *hb = Gtk::manage(new Gtk::HBox());
-            //     hb->pack_start(*curveEditors[i]->curveType->buttonGroup, Gtk::PACK_EXPAND_WIDGET, 3);
-            //     hb->pack_start(*curveEditors[i]->relatedWidget, !rwe ? Gtk::PACK_SHRINK : Gtk::PACK_EXPAND_WIDGET, 3);
+            //     hb->pack_start(*curveEditors[i]->curveType->buttonGroup,
+            //     Gtk::PACK_EXPAND_WIDGET, 3);
+            //     hb->pack_start(*curveEditors[i]->relatedWidget, !rwe ?
+            //     Gtk::PACK_SHRINK : Gtk::PACK_EXPAND_WIDGET, 3);
             //     currLine->attach(*hb, x++, 0, 1, 1);
             // } else {
-            //     currLine->attach(*curveEditors[i]->curveType->buttonGroup, x++, 0, 1, 1);
+            //     currLine->attach(*curveEditors[i]->curveType->buttonGroup,
+            //     x++, 0, 1, 1);
             // }
-            currLine->attach(*curveEditors[i]->curveType->buttonGroup, x++, 0, 1, 1);
+            currLine->attach(*curveEditors[i]->curveType->buttonGroup, x++, 0,
+                             1, 1);
 
             if (curveEditors[i]->relatedWidget != nullptr) {
-                setExpandAlignProperties(curveEditors[i]->relatedWidget, curveEditors[i]->expandRelatedWidget, true, Gtk::ALIGN_FILL, Gtk::ALIGN_FILL);
+                setExpandAlignProperties(curveEditors[i]->relatedWidget,
+                                         curveEditors[i]->expandRelatedWidget,
+                                         true, Gtk::ALIGN_FILL,
+                                         Gtk::ALIGN_FILL);
                 currLine->attach(*curveEditors[i]->relatedWidget, x++, 0, 1, 1);
             }
 
@@ -169,12 +186,15 @@ void CurveEditorGroup::newLine()
         }
 
         if (isHeader) {
-            curve_reset = Gtk::manage (new Gtk::Button ());
-            setExpandAlignProperties(curve_reset, false, false, Gtk::ALIGN_CENTER, Gtk::ALIGN_FILL);
-            curve_reset->add (*Gtk::manage (new RTImage ("undo-small.svg", "redo-small.svg")));
-            curve_reset->set_relief (Gtk::RELIEF_NONE);
-            curve_reset->set_tooltip_text (M("CURVEEDITOR_TOOLTIPLINEAR"));
-            curve_reset->signal_clicked().connect( sigc::mem_fun(*this, &CurveEditorGroup::curveResetPressed) );
+            curve_reset = Gtk::manage(new Gtk::Button());
+            setExpandAlignProperties(curve_reset, false, false,
+                                     Gtk::ALIGN_CENTER, Gtk::ALIGN_FILL);
+            curve_reset->add(
+                *Gtk::manage(new RTImage("undo-small.svg", "redo-small.svg")));
+            curve_reset->set_relief(Gtk::RELIEF_NONE);
+            curve_reset->set_tooltip_text(M("CURVEEDITOR_TOOLTIPLINEAR"));
+            curve_reset->signal_clicked().connect(
+                sigc::mem_fun(*this, &CurveEditorGroup::curveResetPressed));
 
             currLine->attach(*curve_reset, x++, 0, 1, 1);
         }
@@ -183,23 +203,24 @@ void CurveEditorGroup::newLine()
     }
 }
 
-void CurveEditorGroup::attachCurve (Gtk::Grid* curve)
-{
-    pack_start(*curve);
-}
+void CurveEditorGroup::attachCurve(Gtk::Grid *curve) { pack_start(*curve); }
 
 /*
  * Create all the widgets now that the curve list is complete
- * This method should handle all curve number correctly, i.e. eventually display the curve type buttons
- * in a grid (or table)
+ * This method should handle all curve number correctly, i.e. eventually display
+ * the curve type buttons in a grid (or table)
  */
 void CurveEditorGroup::curveListComplete()
 {
     newLine();
 
-    // We check the length of the label ; if it contains only one char (':'), we set it to the right default string
+    // We check the length of the label ; if it contains only one char (':'), we
+    // set it to the right default string
     if (curveGroupLabel->get_label().size() == 1) {
-        curveGroupLabel->set_label(M(curveEditors.size() > 1 ? "CURVEEDITOR_CURVES" : "CURVEEDITOR_CURVE") + ":");
+        curveGroupLabel->set_label(M(curveEditors.size() > 1
+                                         ? "CURVEEDITOR_CURVES"
+                                         : "CURVEEDITOR_CURVE") +
+                                   ":");
     }
 
     if (curveEditors.size() > 1) {
@@ -209,9 +230,10 @@ void CurveEditorGroup::curveListComplete()
 
 /*
  * Callback method used when a curve type button has changed ;
- * it will activate the button, and so emit 'signal_toggled' (-> curveTypeToggled here under)
+ * it will activate the button, and so emit 'signal_toggled' (->
+ * curveTypeToggled here under)
  */
-void CurveEditorGroup::typeSelectionChanged (CurveEditor* ce, int n)
+void CurveEditorGroup::typeSelectionChanged(CurveEditor *ce, int n)
 {
     // Same curve and same type : do nothing
     if (ce == displayedCurve && n == (int)ce->selected) {
@@ -224,7 +246,7 @@ void CurveEditorGroup::typeSelectionChanged (CurveEditor* ce, int n)
 
     // The user selected a new type from a toggled off button
     if (ce != displayedCurve)
-        // We toggle off the other curve: it will emit the toggle off signal
+    // We toggle off the other curve: it will emit the toggle off signal
     {
         hideCurrentCurve();
     }
@@ -232,26 +254,29 @@ void CurveEditorGroup::typeSelectionChanged (CurveEditor* ce, int n)
     // If the button was not pressed before
     if (!ce->curveType->get_active()) {
         ce->subGroup->storeDisplayedCurve();
-        // We set it pressed : it will emit the toggle on signal and update the GUI
-        ce->curveType->set_active( n > ce->subGroup->valLinear && n < ce->subGroup->valUnchanged );
+        // We set it pressed : it will emit the toggle on signal and update the
+        // GUI
+        ce->curveType->set_active(n > ce->subGroup->valLinear &&
+                                  n < ce->subGroup->valUnchanged);
 
         if (n == ce->subGroup->valLinear || n == ce->subGroup->valUnchanged) {
-            // Since we do not activate the curve when the user switch the toggled off button to 'Linear', we have to
-            // to call the curve listener manually, because 'curveChanged' uses displayedCurve...
+            // Since we do not activate the curve when the user switch the
+            // toggled off button to 'Linear', we have to to call the curve
+            // listener manually, because 'curveChanged' uses displayedCurve...
             if (cl) {
                 if (cl->isMulti()) {
-                    cl->curveChanged (ce);
+                    cl->curveChanged(ce);
                 } else {
-                    cl->curveChanged ();
+                    cl->curveChanged();
                 }
             }
         } else {
-            curveChanged ();
+            curveChanged();
         }
     } else {
         // The button is already pressed so we switch the GUI ourselves
         ce->subGroup->switchGUI();
-        curveChanged ();
+        curveChanged();
     }
 }
 
@@ -259,21 +284,23 @@ void CurveEditorGroup::typeSelectionChanged (CurveEditor* ce, int n)
  * Callback method used when a button has been toggled on/off
  * It then hide any other displayed curve and display it's curve
  */
-void CurveEditorGroup::curveTypeToggled(CurveEditor* ce)
+void CurveEditorGroup::curveTypeToggled(CurveEditor *ce)
 {
     bool curveRestored = false;
 
     if (displayedCurve) {
-        EditDataProvider* editProvider = displayedCurve->getEditProvider();
+        EditDataProvider *editProvider = displayedCurve->getEditProvider();
 
-        if (editProvider && editProvider->getCurrSubscriber() == displayedCurve) {
+        if (editProvider &&
+            editProvider->getCurrSubscriber() == displayedCurve) {
             displayedCurve->switchOffEditMode();
         }
     }
 
     // Looking for the button state
     if (ce->curveType->get_active()) {
-        // The button is now pressed, so we have to first hide all other CurveEditor
+        // The button is now pressed, so we have to first hide all other
+        // CurveEditor
         hideCurrentCurve();
 
         displayedCurve = ce;
@@ -297,27 +324,28 @@ void CurveEditorGroup::curveTypeToggled(CurveEditor* ce)
     ce->subGroup->switchGUI();
 
     if (curveRestored) {
-        curveChanged ();
+        curveChanged();
     }
-
 }
 
 /*
  * Update the GUI if the given curveEditor is currently displayed
  */
-void CurveEditorGroup::updateGUI (CurveEditor* ce)
+void CurveEditorGroup::updateGUI(CurveEditor *ce)
 {
     if (!ce) {
         return;
     }
 
-    // we update the curve type button to the corresponding curve type, only if it is not currently set to 'Unchanged'
+    // we update the curve type button to the corresponding curve type, only if
+    // it is not currently set to 'Unchanged'
     if (ce->curveType->getSelected() < ce->subGroup->valUnchanged) {
         ce->curveType->setSelected(ce->selected);
     }
 
     // if not displayed or "unchanged" is selected, do not change gui
-    if (ce == displayedCurve && ce->curveType->getSelected() < ce->subGroup->valUnchanged) {
+    if (ce == displayedCurve &&
+        ce->curveType->getSelected() < ce->subGroup->valUnchanged) {
         ce->subGroup->switchGUI();
     }
 }
@@ -325,29 +353,33 @@ void CurveEditorGroup::updateGUI (CurveEditor* ce)
 /*
  * Called from the outside to set the curve type & values
  */
-void CurveEditorGroup::setCurveExternal (CurveEditor* ce, const std::vector<double>& c)
+void CurveEditorGroup::setCurveExternal(CurveEditor *ce,
+                                        const std::vector<double> &c)
 {
     if (!c.empty()) {
-        ce->subGroup->storeCurveValues(ce, c);  // The new curve is saved in the CurveEditor
-        (ce)->selected = c[0];      // We set the selected curve type in the CurveEditor to the one of the specified curve
+        ce->subGroup->storeCurveValues(
+            ce, c);            // The new curve is saved in the CurveEditor
+        (ce)->selected = c[0]; // We set the selected curve type in the
+                               // CurveEditor to the one of the specified curve
     }
 
-    updateGUI(static_cast<CurveEditor*>(ce));               // And we update the GUI if necessary
+    updateGUI(
+        static_cast<CurveEditor *>(ce)); // And we update the GUI if necessary
 }
 
 /*
  * Listener called when the user has modified the curve
  */
-void CurveEditorGroup::curveChanged ()
+void CurveEditorGroup::curveChanged()
 {
 
     displayedCurve->subGroup->storeDisplayedCurve();
 
     if (cl) {
         if (cl->isMulti()) {
-            cl->curveChanged (displayedCurve);
+            cl->curveChanged(displayedCurve);
         } else {
-            cl->curveChanged ();
+            cl->curveChanged();
         }
     }
 }
@@ -355,7 +387,8 @@ void CurveEditorGroup::curveChanged ()
 /*
  * Listener called when the user has modified the curve
  */
-float CurveEditorGroup::blendPipetteValues (CurveEditor* ce, float chan1, float chan2, float chan3)
+float CurveEditorGroup::blendPipetteValues(CurveEditor *ce, float chan1,
+                                           float chan2, float chan3)
 {
 
     if (cl) {
@@ -369,7 +402,7 @@ float CurveEditorGroup::blendPipetteValues (CurveEditor* ce, float chan1, float
  * Call back method when the reset button is pressed :
  * reset the currently toggled on curve editor
  */
-void CurveEditorGroup::curveResetPressed ()
+void CurveEditorGroup::curveResetPressed()
 {
     if (displayedCurve) {
         if (displayedCurve->subGroup->curveReset(displayedCurve)) {
@@ -381,33 +414,37 @@ void CurveEditorGroup::curveResetPressed ()
 /*
  * Set the tooltip text of the label of the curve group
  */
-void CurveEditorGroup::setTooltip( Glib::ustring ttip)
+void CurveEditorGroup::setTooltip(Glib::ustring ttip)
 {
-    curveGroupLabel->set_tooltip_text( ttip );
+    curveGroupLabel->set_tooltip_text(ttip);
 }
 
-void CurveEditorGroup::setUnChanged (bool uc, CurveEditor* ce)
+void CurveEditorGroup::setUnChanged(bool uc, CurveEditor *ce)
 {
     if (uc) {
-        // the user selected several thumbnails, so we hide the editors and set the curveEditor selection to 'Unchanged'
-        //ce->typeconn.block(true);
+        // the user selected several thumbnails, so we hide the editors and set
+        // the curveEditor selection to 'Unchanged'
+        // ce->typeconn.block(true);
         // we hide the editor widgets
         hideCurrentCurve();
         // the curve type selected option is set to unchanged
         ce->curveType->setSelected(ce->subGroup->valUnchanged);
-        //ce->typeconn.block(false);
+        // ce->typeconn.block(false);
     } else {
-        // we want it to use back the 'CurveEditor::setCurve' memorized in CurveEditor::tempCurve
-        //ce->typeconn.block(true);
-        // we switch back the curve type selected option to the one of the used curve
+        // we want it to use back the 'CurveEditor::setCurve' memorized in
+        // CurveEditor::tempCurve
+        // ce->typeconn.block(true);
+        // we switch back the curve type selected option to the one of the used
+        // curve
         ce->curveType->setSelected(ce->selected);
-        updateGUI (ce);
-        //ce->typeconn.block(false);
+        updateGUI(ce);
+        // ce->typeconn.block(false);
     }
 }
 
-
-CurveEditorSubGroup::CurveEditorSubGroup(Glib::ustring& curveDir) : curveDir(curveDir), lastFilename(""), valLinear(0), valUnchanged(0), parent(nullptr)
+CurveEditorSubGroup::CurveEditorSubGroup(Glib::ustring &curveDir)
+    : curveDir(curveDir), lastFilename(""), valLinear(0), valUnchanged(0),
+      parent(nullptr)
 {
     leftBar = nullptr;
     bottomBar = nullptr;
@@ -424,7 +461,10 @@ CurveEditorSubGroup::~CurveEditorSubGroup()
     }
 }
 
-void CurveEditorSubGroup::initButton (Gtk::Button &button, const Glib::ustring &iconName, Gtk::Align align, bool separatorButton, const Glib::ustring &tooltip)
+void CurveEditorSubGroup::initButton(Gtk::Button &button,
+                                     const Glib::ustring &iconName,
+                                     Gtk::Align align, bool separatorButton,
+                                     const Glib::ustring &tooltip)
 {
     bool hExpand, vExpand;
     if (separatorButton) {
@@ -435,14 +475,22 @@ void CurveEditorSubGroup::initButton (Gtk::Button &button, const Glib::ustring &
     }
     Gtk::Align hAlign, vAlign;
     if (align == Gtk::ALIGN_START) {
-        hAlign = options.curvebboxpos == 0 || options.curvebboxpos == 2 ? Gtk::ALIGN_START : Gtk::ALIGN_FILL;
-        vAlign = options.curvebboxpos == 0 || options.curvebboxpos == 2 ? Gtk::ALIGN_FILL : Gtk::ALIGN_START;
+        hAlign = options.curvebboxpos == 0 || options.curvebboxpos == 2
+                     ? Gtk::ALIGN_START
+                     : Gtk::ALIGN_FILL;
+        vAlign = options.curvebboxpos == 0 || options.curvebboxpos == 2
+                     ? Gtk::ALIGN_FILL
+                     : Gtk::ALIGN_START;
     } else {
-        hAlign = options.curvebboxpos == 0 || options.curvebboxpos == 2 ?  Gtk::ALIGN_END : Gtk::ALIGN_FILL;
-        vAlign = options.curvebboxpos == 0 || options.curvebboxpos == 2 ?  Gtk::ALIGN_FILL : Gtk::ALIGN_END;
+        hAlign = options.curvebboxpos == 0 || options.curvebboxpos == 2
+                     ? Gtk::ALIGN_END
+                     : Gtk::ALIGN_FILL;
+        vAlign = options.curvebboxpos == 0 || options.curvebboxpos == 2
+                     ? Gtk::ALIGN_FILL
+                     : Gtk::ALIGN_END;
     }
 
-    button.add (*Gtk::manage (new RTImage (iconName)));
+    button.add(*Gtk::manage(new RTImage(iconName)));
     button.get_style_context()->add_class(GTK_STYLE_CLASS_FLAT);
     if (!tooltip.empty()) {
         button.set_tooltip_text(M(tooltip));
@@ -450,7 +498,9 @@ void CurveEditorSubGroup::initButton (Gtk::Button &button, const Glib::ustring &
     setExpandAlignProperties(&button, hExpand, vExpand, hAlign, vAlign);
 }
 
-void CurveEditorSubGroup::updateEditButton(CurveEditor* curve, Gtk::ToggleButton *button, sigc::connection &connection)
+void CurveEditorSubGroup::updateEditButton(CurveEditor *curve,
+                                           Gtk::ToggleButton *button,
+                                           sigc::connection &connection)
 {
     if (!curve->getEditProvider() || curve->getEditID() == EUID_None) {
         button->hide();
@@ -470,12 +520,14 @@ void CurveEditorSubGroup::updateEditButton(CurveEditor* curve, Gtk::ToggleButton
     }
 }
 
-Glib::ustring CurveEditorSubGroup::outputFile ()
+Glib::ustring CurveEditorSubGroup::outputFile()
 {
 
-    Gtk::FileChooserDialog dialog (getToplevelWindow (parent), M("CURVEEDITOR_SAVEDLGLABEL"), Gtk::FILE_CHOOSER_ACTION_SAVE);
-    bindCurrentFolder (dialog, curveDir);
-    dialog.set_current_name (lastFilename);
+    Gtk::FileChooserDialog dialog(getToplevelWindow(parent),
+                                  M("CURVEEDITOR_SAVEDLGLABEL"),
+                                  Gtk::FILE_CHOOSER_ACTION_SAVE);
+    bindCurrentFolder(dialog, curveDir);
+    dialog.set_current_name(lastFilename);
 
     dialog.add_button(M("GENERAL_CANCEL"), Gtk::RESPONSE_CANCEL);
     dialog.add_button(M("GENERAL_SAVE"), Gtk::RESPONSE_APPLY);
@@ -490,7 +542,7 @@ Glib::ustring CurveEditorSubGroup::outputFile ()
     filter_any->add_pattern("*");
     dialog.add_filter(filter_any);
 
-    //dialog.set_do_overwrite_confirmation (true);
+    // dialog.set_do_overwrite_confirmation (true);
 
     Glib::ustring fname;
 
@@ -498,12 +550,12 @@ Glib::ustring CurveEditorSubGroup::outputFile ()
         if (dialog.run() == Gtk::RESPONSE_APPLY) {
             fname = dialog.get_filename();
 
-            if (getExtension (fname) != "rtc") {
+            if (getExtension(fname) != "rtc") {
                 fname += ".rtc";
             }
 
-            if (confirmOverwrite (dialog, fname)) {
-                lastFilename = Glib::path_get_basename (fname);
+            if (confirmOverwrite(dialog, fname)) {
+                lastFilename = Glib::path_get_basename(fname);
                 break;
             }
         } else {
@@ -515,11 +567,13 @@ Glib::ustring CurveEditorSubGroup::outputFile ()
     return fname;
 }
 
-Glib::ustring CurveEditorSubGroup::inputFile ()
+Glib::ustring CurveEditorSubGroup::inputFile()
 {
 
-    Gtk::FileChooserDialog dialog (getToplevelWindow (parent), M("CURVEEDITOR_LOADDLGLABEL"), Gtk::FILE_CHOOSER_ACTION_OPEN);
-    bindCurrentFolder (dialog, curveDir);
+    Gtk::FileChooserDialog dialog(getToplevelWindow(parent),
+                                  M("CURVEEDITOR_LOADDLGLABEL"),
+                                  Gtk::FILE_CHOOSER_ACTION_OPEN);
+    bindCurrentFolder(dialog, curveDir);
 
     dialog.add_button(M("GENERAL_CANCEL"), Gtk::RESPONSE_CANCEL);
     dialog.add_button(M("GENERAL_APPLY"), Gtk::RESPONSE_APPLY);
@@ -541,7 +595,7 @@ Glib::ustring CurveEditorSubGroup::inputFile ()
     if (result == Gtk::RESPONSE_APPLY) {
         fname = dialog.get_filename();
 
-        if (Glib::file_test (fname, Glib::FILE_TEST_EXISTS)) {
+        if (Glib::file_test(fname, Glib::FILE_TEST_EXISTS)) {
             return fname;
         }
     }
