@@ -1,18 +1,19 @@
 #include "gdkcolormgmt.h"
 #include "options.h"
 #ifdef __APPLE__
-#  include <ApplicationServices/ApplicationServices.h>
-#endif 
+#include <ApplicationServices/ApplicationServices.h>
+#endif
 #include <stdio.h>
 
 #include <gdk/gdkconfig.h>
 #ifdef GDK_WINDOWING_QUARTZ
-# include <gdk/gdkquartz.h>
+#include <gdk/gdkquartz.h>
 #endif
 
 namespace art {
 
-void gdk_set_monitor_profile(GdkWindow *window, rtengine::Settings::StdMonitorProfile prof)
+void gdk_set_monitor_profile(GdkWindow *window,
+                             rtengine::Settings::StdMonitorProfile prof)
 {
 #if defined __APPLE__ && defined GDK_QUARTZ_WINDOW_SUPPORTS_COLORSPACE
     auto colorspace = kCGColorSpaceSRGB;
@@ -28,12 +29,15 @@ void gdk_set_monitor_profile(GdkWindow *window, rtengine::Settings::StdMonitorPr
     }
     const char *csp = g_getenv("ART_DEBUG_GDK_QUARTZ_COLORSPACE");
     if (csp) {
-        colorspace = CFStringCreateWithCString(NULL, csp, kCFStringEncodingUTF8);
+        colorspace =
+            CFStringCreateWithCString(NULL, csp, kCFStringEncodingUTF8);
     }
     if (options.rtSettings.verbose > 1) {
-        fprintf(stderr, "gdk_set_monitor_profile: %s\n", CFStringGetCStringPtr(colorspace, kCFStringEncodingUTF8));
+        fprintf(stderr, "gdk_set_monitor_profile: %s\n",
+                CFStringGetCStringPtr(colorspace, kCFStringEncodingUTF8));
     }
-    g_object_set_data(G_OBJECT(window), "gdk-quartz-colorspace", (gpointer)colorspace);
+    g_object_set_data(G_OBJECT(window), "gdk-quartz-colorspace",
+                      (gpointer)colorspace);
 #endif
 }
 
