@@ -16,65 +16,65 @@
  *  You should have received a copy of the GNU General Public License
  *  along with RawTherapee.  If not, see <http://www.gnu.org/licenses/>.
  */
-#include <set>
 #include "history.h"
+#include "eventmapper.h"
+#include "guiutils.h"
 #include "multilangmgr.h"
 #include "rtimage.h"
-#include "guiutils.h"
-#include "eventmapper.h"
+#include <set>
 
 #include <iostream>
 
 using namespace rtengine;
 using namespace rtengine::procparams;
 
-
-History::History (bool bookmarkSupport) :
-    historyVPaned(nullptr),
-    blistener(nullptr),
-    tpc(nullptr),
-    bmnum(1),
-    snapshotListener(nullptr),
-    shapshot_update_(false)
+History::History(bool bookmarkSupport)
+    : historyVPaned(nullptr), blistener(nullptr), tpc(nullptr), bmnum(1),
+      snapshotListener(nullptr), shapshot_update_(false)
 {
 
-    blistenerLock = false; // sets default that the Before preview will not be locked
+    blistenerLock =
+        false; // sets default that the Before preview will not be locked
     // History List
     // ~~~~~~~~~~~~
-    Gtk::ScrolledWindow* hscrollw = Gtk::manage (new Gtk::ScrolledWindow ());
-    hscrollw->set_policy (Gtk::POLICY_NEVER, Gtk::POLICY_AUTOMATIC);
+    Gtk::ScrolledWindow *hscrollw = Gtk::manage(new Gtk::ScrolledWindow());
+    hscrollw->set_policy(Gtk::POLICY_NEVER, Gtk::POLICY_AUTOMATIC);
 
-    Gtk::Frame* histFrame = Gtk::manage (new Gtk::Frame (M("HISTORY_LABEL")));
+    Gtk::Frame *histFrame = Gtk::manage(new Gtk::Frame(M("HISTORY_LABEL")));
     histFrame->set_label_align(0.025, 0.5);
-    histFrame->set_name ("HistoryPanel");
-    histFrame->add (*hscrollw);
+    histFrame->set_name("HistoryPanel");
+    histFrame->add(*hscrollw);
 
-    hTreeView = Gtk::manage (new Gtk::TreeView ());
-    hscrollw->add (*hTreeView);
+    hTreeView = Gtk::manage(new Gtk::TreeView());
+    hscrollw->add(*hTreeView);
 
-    historyModel = Gtk::ListStore::create (historyColumns);
-    hTreeView->set_model (historyModel);
-    hTreeView->set_headers_visible (false);
+    historyModel = Gtk::ListStore::create(historyColumns);
+    hTreeView->set_model(historyModel);
+    hTreeView->set_headers_visible(false);
     hTreeView->set_hscroll_policy(Gtk::SCROLL_MINIMUM);
     hTreeView->set_vscroll_policy(Gtk::SCROLL_NATURAL);
     hTreeView->set_size_request(80, -1);
 
-    Gtk::CellRendererText *changecrt = Gtk::manage (new Gtk::CellRendererText());
+    Gtk::CellRendererText *changecrt = Gtk::manage(new Gtk::CellRendererText());
     changecrt->property_ellipsize() = Pango::ELLIPSIZE_END;
-    Gtk::CellRendererText *valuecrt  = Gtk::manage (new Gtk::CellRendererText());
+    Gtk::CellRendererText *valuecrt = Gtk::manage(new Gtk::CellRendererText());
     valuecrt->property_ellipsize() = Pango::ELLIPSIZE_END;
-    Gtk::TreeView::Column *hviewcol = Gtk::manage (new Gtk::TreeView::Column (""));
-    hviewcol->pack_start (*changecrt, true);
-    hviewcol->add_attribute (changecrt->property_text()/*markup ()*/, historyColumns.text);
+    Gtk::TreeView::Column *hviewcol =
+        Gtk::manage(new Gtk::TreeView::Column(""));
+    hviewcol->pack_start(*changecrt, true);
+    hviewcol->add_attribute(changecrt->property_text() /*markup ()*/,
+                            historyColumns.text);
     hviewcol->set_expand(true);
-    hviewcol->set_resizable (true);
+    hviewcol->set_resizable(true);
     hviewcol->set_fixed_width(35);
     hviewcol->set_min_width(35);
     hviewcol->set_sizing(Gtk::TREE_VIEW_COLUMN_AUTOSIZE);
 
-    Gtk::TreeView::Column *hviewcol2 = Gtk::manage (new Gtk::TreeView::Column (""));
-    hviewcol2->pack_start (*valuecrt, true);
-    hviewcol2->add_attribute (valuecrt->property_text()/*markup ()*/, historyColumns.value);
+    Gtk::TreeView::Column *hviewcol2 =
+        Gtk::manage(new Gtk::TreeView::Column(""));
+    hviewcol2->pack_start(*valuecrt, true);
+    hviewcol2->add_attribute(valuecrt->property_text() /*markup ()*/,
+                             historyColumns.value);
     hviewcol2->set_expand(true);
     hviewcol2->set_resizable(true);
     hviewcol2->set_fixed_width(35);
@@ -83,95 +83,105 @@ History::History (bool bookmarkSupport) :
     valuecrt->set_alignment(1.f, 0.f);
 
     hTreeView->set_has_tooltip(true);
-    hTreeView->signal_query_tooltip().connect( sigc::mem_fun(*this, &History::on_query_tooltip) );
-    hTreeView->append_column (*hviewcol);
-    hTreeView->append_column (*hviewcol2);
+    hTreeView->signal_query_tooltip().connect(
+        sigc::mem_fun(*this, &History::on_query_tooltip));
+    hTreeView->append_column(*hviewcol);
+    hTreeView->append_column(*hviewcol2);
 
-    selchangehist = hTreeView->get_selection()->signal_changed().connect(sigc::mem_fun(*this, &History::historySelectionChanged));
+    selchangehist = hTreeView->get_selection()->signal_changed().connect(
+        sigc::mem_fun(*this, &History::historySelectionChanged));
 
     // Bookmark List
     // ~~~~~~~~~~~~~
 
-    Gtk::HBox* ahbox = Gtk::manage (new Gtk::HBox ());
-    addBookmark = Gtk::manage (new Gtk::Button ());  // M("HISTORY_NEWSNAPSHOT")
-    setExpandAlignProperties(addBookmark, true, false, Gtk::ALIGN_FILL, Gtk::ALIGN_START);
-    //addBookmark->get_style_context()->set_junction_sides(Gtk::JUNCTION_RIGHT);
+    Gtk::HBox *ahbox = Gtk::manage(new Gtk::HBox());
+    addBookmark = Gtk::manage(new Gtk::Button()); // M("HISTORY_NEWSNAPSHOT")
+    setExpandAlignProperties(addBookmark, true, false, Gtk::ALIGN_FILL,
+                             Gtk::ALIGN_START);
+    // addBookmark->get_style_context()->set_junction_sides(Gtk::JUNCTION_RIGHT);
     addBookmark->get_style_context()->add_class("Left");
-    addBookmark->set_tooltip_markup (M("HISTORY_NEWSNAPSHOT_TOOLTIP"));
-    Gtk::Image* addimg = Gtk::manage (new RTImage ("add-small.svg"));
-    addBookmark->set_image (*addimg);
-    ahbox->pack_start (*addBookmark);
+    addBookmark->set_tooltip_markup(M("HISTORY_NEWSNAPSHOT_TOOLTIP"));
+    Gtk::Image *addimg = Gtk::manage(new RTImage("add-small.svg"));
+    addBookmark->set_image(*addimg);
+    ahbox->pack_start(*addBookmark);
 
-    delBookmark = Gtk::manage (new Gtk::Button ());  // M("HISTORY_DELSNAPSHOT")
-    setExpandAlignProperties(delBookmark, true, false, Gtk::ALIGN_FILL, Gtk::ALIGN_START);
-    //delBookmark->get_style_context()->set_junction_sides(Gtk::JUNCTION_LEFT);
+    delBookmark = Gtk::manage(new Gtk::Button()); // M("HISTORY_DELSNAPSHOT")
+    setExpandAlignProperties(delBookmark, true, false, Gtk::ALIGN_FILL,
+                             Gtk::ALIGN_START);
+    // delBookmark->get_style_context()->set_junction_sides(Gtk::JUNCTION_LEFT);
     delBookmark->get_style_context()->add_class("Right");
-    Gtk::Image* delimg = Gtk::manage (new RTImage ("remove-small.svg"));
-    delBookmark->set_image (*delimg);
-    ahbox->pack_start (*delBookmark);
+    Gtk::Image *delimg = Gtk::manage(new RTImage("remove-small.svg"));
+    delBookmark->set_image(*delimg);
+    ahbox->pack_start(*delBookmark);
 
-    bscrollw = Gtk::manage (new Gtk::ScrolledWindow ());
-//    bscrollw->set_policy (Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
-    bscrollw->set_policy (Gtk::POLICY_NEVER, Gtk::POLICY_AUTOMATIC);
-    bscrollw->set_size_request (-1, 45);
+    bscrollw = Gtk::manage(new Gtk::ScrolledWindow());
+    //    bscrollw->set_policy (Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
+    bscrollw->set_policy(Gtk::POLICY_NEVER, Gtk::POLICY_AUTOMATIC);
+    bscrollw->set_size_request(-1, 45);
 
-    Gtk::Frame* bmFrame = Gtk::manage (new Gtk::Frame (M("HISTORY_SNAPSHOTS")));
+    Gtk::Frame *bmFrame = Gtk::manage(new Gtk::Frame(M("HISTORY_SNAPSHOTS")));
     bmFrame->set_label_align(0.025, 0.5);
     bmFrame->set_name("Snapshots");
-    Gtk::VBox* bmBox = Gtk::manage (new Gtk::VBox ());
-    bmFrame->add (*bmBox);
-    bmBox->pack_start (*bscrollw, Gtk::PACK_EXPAND_WIDGET, 4);
-    bmBox->pack_end (*ahbox, Gtk::PACK_SHRINK, 4);
-    bmBox->set_size_request(-1,100);
+    Gtk::VBox *bmBox = Gtk::manage(new Gtk::VBox());
+    bmFrame->add(*bmBox);
+    bmBox->pack_start(*bscrollw, Gtk::PACK_EXPAND_WIDGET, 4);
+    bmBox->pack_end(*ahbox, Gtk::PACK_SHRINK, 4);
+    bmBox->set_size_request(-1, 100);
 
     if (bookmarkSupport) {
-        historyVPaned = Gtk::manage ( new Gtk::VPaned () );
-        historyVPaned->pack1 (*histFrame, true, true);
-        historyVPaned->pack2 (*bmFrame, false, false);
+        historyVPaned = Gtk::manage(new Gtk::VPaned());
+        historyVPaned->pack1(*histFrame, true, true);
+        historyVPaned->pack2(*bmFrame, false, false);
         pack_start(*historyVPaned);
     } else {
-        pack_start (*histFrame);
+        pack_start(*histFrame);
     }
 
+    bTreeView = Gtk::manage(new Gtk::TreeView());
+    bscrollw->add(*bTreeView);
 
-    bTreeView = Gtk::manage (new Gtk::TreeView ());
-    bscrollw->add (*bTreeView);
+    bookmarkModel = Gtk::ListStore::create(bookmarkColumns);
+    bTreeView->set_model(bookmarkModel);
+    bTreeView->set_headers_visible(false);
+    bTreeView->append_column_editable(M("HISTORY_SNAPSHOTS"),
+                                      bookmarkColumns.text);
 
-    bookmarkModel = Gtk::ListStore::create (bookmarkColumns);
-    bTreeView->set_model (bookmarkModel);
-    bTreeView->set_headers_visible (false);
-    bTreeView->append_column_editable (M("HISTORY_SNAPSHOTS"), bookmarkColumns.text);
-
-    selchangebm = bTreeView->get_selection()->signal_changed().connect(sigc::mem_fun(*this, &History::bookmarkSelectionChanged));
+    selchangebm = bTreeView->get_selection()->signal_changed().connect(
+        sigc::mem_fun(*this, &History::bookmarkSelectionChanged));
     bTreeView->add_events(Gdk::BUTTON_PRESS_MASK);
-    bTreeView->signal_button_press_event().connect(sigc::mem_fun(*this, &History::onPressEvent), false);
+    bTreeView->signal_button_press_event().connect(
+        sigc::mem_fun(*this, &History::onPressEvent), false);
 
-    addBookmark->signal_clicked().connect( sigc::mem_fun(*this, &History::addBookmarkPressed) );
-    delBookmark->signal_clicked().connect( sigc::mem_fun(*this, &History::delBookmarkPressed) );
-    static_cast<Gtk::CellRendererText *>(bTreeView->get_column_cell_renderer(0))->signal_edited().connect(sigc::mem_fun(*this, &History::snapshotNameEdited));
-    static_cast<Gtk::CellRendererText *>(bTreeView->get_column_cell_renderer(0))->property_ellipsize() = Pango::ELLIPSIZE_MIDDLE;
+    addBookmark->signal_clicked().connect(
+        sigc::mem_fun(*this, &History::addBookmarkPressed));
+    delBookmark->signal_clicked().connect(
+        sigc::mem_fun(*this, &History::delBookmarkPressed));
+    static_cast<Gtk::CellRendererText *>(bTreeView->get_column_cell_renderer(0))
+        ->signal_edited()
+        .connect(sigc::mem_fun(*this, &History::snapshotNameEdited));
+    static_cast<Gtk::CellRendererText *>(bTreeView->get_column_cell_renderer(0))
+        ->property_ellipsize() = Pango::ELLIPSIZE_MIDDLE;
 
-
-    //hTreeView->set_grid_lines (Gtk::TREE_VIEW_GRID_LINES_HORIZONTAL);
-    hTreeView->set_grid_lines (Gtk::TREE_VIEW_GRID_LINES_BOTH);
-    //hTreeView->signal_size_allocate().connect( sigc::mem_fun(*this, &History::resized) );
+    // hTreeView->set_grid_lines (Gtk::TREE_VIEW_GRID_LINES_HORIZONTAL);
+    hTreeView->set_grid_lines(Gtk::TREE_VIEW_GRID_LINES_BOTH);
+    // hTreeView->signal_size_allocate().connect( sigc::mem_fun(*this,
+    // &History::resized) );
 
     hTreeView->set_enable_search(false);
     bTreeView->set_enable_search(false);
 
-    show_all_children ();
+    show_all_children();
 }
 
-
-void History::initHistory ()
+void History::initHistory()
 {
 
     ConnectionBlocker selBlocker(selchangehist);
-    historyModel->clear ();
-    bookmarkModel->clear ();
+    historyModel->clear();
+    bookmarkModel->clear();
 }
 
-void History::historySelectionChanged ()
+void History::historySelectionChanged()
 {
 
     Glib::RefPtr<Gtk::TreeSelection> selection = hTreeView->get_selection();
@@ -181,7 +191,7 @@ void History::historySelectionChanged ()
         Gtk::TreeModel::Row row = *iter;
 
         if (row) {
-            bTreeView->get_selection()->unselect_all ();
+            bTreeView->get_selection()->unselect_all();
         }
 
         if (row && tpc) {
@@ -190,7 +200,8 @@ void History::historySelectionChanged ()
             // PartialProfile pp(&pparams, &pe);
             // ParamsEdited paramsEdited = row[historyColumns.paramsEdited];
             FullPartialProfile pp(pparams);
-            tpc->profileChange (&pp, EvHistoryBrowsed, row[historyColumns.text], nullptr);//&paramsEdited);
+            tpc->profileChange(&pp, EvHistoryBrowsed, row[historyColumns.text],
+                               nullptr); //&paramsEdited);
         }
 
         if (blistener && !blistenerLock) {
@@ -199,13 +210,14 @@ void History::historySelectionChanged ()
             // iter = historyModel->get_iter (path);
 
             if (blistener && iter) {
-                blistener->historyBeforeAfterChanged (iter->get_value (historyColumns.params));
+                blistener->historyBeforeAfterChanged(
+                    iter->get_value(historyColumns.params));
             }
         }
     }
 }
 
-void History::bookmarkSelectionChanged ()
+void History::bookmarkSelectionChanged()
 {
 
     Glib::RefPtr<Gtk::TreeSelection> selection = bTreeView->get_selection();
@@ -221,7 +233,8 @@ void History::bookmarkSelectionChanged ()
                 iter = selection->get_selected();
                 if (!iter && historyModel->children().size() > 0) {
                     iter = historyModel->children().begin();
-                    for (size_t i = 1; i < historyModel->children().size(); ++i) {
+                    for (size_t i = 1; i < historyModel->children().size();
+                         ++i) {
                         ++iter;
                     }
                 }
@@ -244,38 +257,39 @@ void History::bookmarkSelectionChanged ()
                 const auto &pparams = row[bookmarkColumns.params];
                 // ParamsEdited pe(true);
                 // PartialProfile pp(&pparams, &pe);
-                // ParamsEdited paramsEdited = row[bookmarkColumns.paramsEdited];
+                // ParamsEdited paramsEdited =
+                // row[bookmarkColumns.paramsEdited];
                 FullPartialProfile pp(pparams);
-                tpc->profileChange (&pp, EvBookmarkSelected, row[bookmarkColumns.text], nullptr);//&paramsEdited);
+                tpc->profileChange(&pp, EvBookmarkSelected,
+                                   row[bookmarkColumns.text],
+                                   nullptr); //&paramsEdited);
             }
         }
     }
 }
 
-void History::procParamsChanged(
-    const ProcParams* params,
-    const ProcEvent& ev,
-    const Glib::ustring& descr,
-    const ParamsEdited* paramsEdited
-)
+void History::procParamsChanged(const ProcParams *params, const ProcEvent &ev,
+                                const Glib::ustring &descr,
+                                const ParamsEdited *paramsEdited)
 {
-    // to prevent recursion, we filter out the events triggered by the history and events that should not be registered
+    // to prevent recursion, we filter out the events triggered by the history
+    // and events that should not be registered
     if (ev == EvHistoryBrowsed || ev == EvMonitorTransform) {
         return;
     }
 
     // construct formatted list content
     Glib::ustring text = M(ProcEventMapper::getInstance()->getHistoryMsg(ev));
-    
+
     if (text.empty() && descr.empty()) {
         return;
     }
 
-    selchangehist.block (true);
-    selchangebm.block (true);
+    selchangehist.block(true);
+    selchangebm.block(true);
 
     if (ev == EvPhotoLoaded) {
-        initHistory ();
+        initHistory();
     }
 
     Glib::RefPtr<Gtk::TreeSelection> selection = hTreeView->get_selection();
@@ -286,12 +300,12 @@ void History::procParamsChanged(
         ++iter;
 
         while (iter) {
-            iter = historyModel->erase (iter);
+            iter = historyModel->erase(iter);
         }
     }
 
     // lookup the last remaining item in the list
-    int size = historyModel->children().size ();
+    int size = historyModel->children().size();
     Gtk::TreeModel::Row row;
 
     if (size > 0) {
@@ -299,22 +313,26 @@ void History::procParamsChanged(
     }
 
     // if there is no last item or its chev!=ev, create a new one
-    if (size == 0 || !row || row[historyColumns.chev] != ev  || ev == EvProfileChanged) {
+    if (size == 0 || !row || row[historyColumns.chev] != ev ||
+        ev == EvProfileChanged) {
         Gtk::TreeModel::Row newrow = *(historyModel->append());
-        newrow[historyColumns.text] = text;//escapeHtmlChars(text);
-        newrow[historyColumns.value] = descr;//g_markup_escape_text(descr.c_str(), -1);
+        newrow[historyColumns.text] = text; // escapeHtmlChars(text);
+        newrow[historyColumns.value] =
+            descr; // g_markup_escape_text(descr.c_str(), -1);
         newrow[historyColumns.chev] = ev;
         newrow[historyColumns.params] = *params;
-        //newrow[historyColumns.paramsEdited] = paramsEdited ? *paramsEdited : defParamsEdited;
+        // newrow[historyColumns.paramsEdited] = paramsEdited ? *paramsEdited :
+        // defParamsEdited;
 
         if (ev != EvBookmarkSelected) {
-            selection->select (newrow);
+            selection->select(newrow);
         }
 
         if (blistener && /*row &&*/ !blistenerLock) {
-        //     blistener->historyBeforeAfterChanged (row[historyColumns.params]);
-        // } else if (blistener && size == 0 && !blistenerLock) {
-            blistener->historyBeforeAfterChanged (newrow[historyColumns.params]);
+            //     blistener->historyBeforeAfterChanged
+            //     (row[historyColumns.params]);
+            // } else if (blistener && size == 0 && !blistenerLock) {
+            blistener->historyBeforeAfterChanged(newrow[historyColumns.params]);
         }
     }
     // else just update it
@@ -323,36 +341,33 @@ void History::procParamsChanged(
         row[historyColumns.value] = g_markup_escape_text(descr.c_str(), -1);
         row[historyColumns.chev] = ev;
         row[historyColumns.params] = *params;
-        //row[historyColumns.paramsEdited] = paramsEdited ? *paramsEdited : defParamsEdited;
+        // row[historyColumns.paramsEdited] = paramsEdited ? *paramsEdited :
+        // defParamsEdited;
 
         if (ev != EvBookmarkSelected) {
-            selection->select (row);
+            selection->select(row);
         }
         if (blistener && /*row &&*/ !blistenerLock) {
-            blistener->historyBeforeAfterChanged (row[historyColumns.params]);
+            blistener->historyBeforeAfterChanged(row[historyColumns.params]);
         }
     }
 
     if (ev != EvBookmarkSelected) {
-        bTreeView->get_selection()->unselect_all ();
+        bTreeView->get_selection()->unselect_all();
     }
 
-
     if (!selection->get_selected_rows().empty()) {
         std::vector<Gtk::TreeModel::Path> selp = selection->get_selected_rows();
-        hTreeView->scroll_to_row (*selp.begin());
+        hTreeView->scroll_to_row(*selp.begin());
     }
 
-    selchangehist.block (false);
-    selchangebm.block (false);
+    selchangehist.block(false);
+    selchangebm.block(false);
 }
 
-void History::clearParamChanges ()
-{
-    initHistory ();
-}
+void History::clearParamChanges() { initHistory(); }
 
-void History::addBookmarkWithText (Glib::ustring text)
+void History::addBookmarkWithText(Glib::ustring text)
 {
     // lookup the selected item in the history
     Glib::RefPtr<Gtk::TreeSelection> selection = hTreeView->get_selection();
@@ -365,17 +380,18 @@ void History::addBookmarkWithText (Glib::ustring text)
 
     // append new row to bookmarks
     auto newit = bookmarkModel->append();
-    Gtk::TreeModel::Row newrow = *newit;//(bookmarkModel->append());
+    Gtk::TreeModel::Row newrow = *newit; //(bookmarkModel->append());
     newrow[bookmarkColumns.text] = text;
     ProcParams params = row[historyColumns.params];
     newrow[bookmarkColumns.params] = params;
     // ParamsEdited paramsEdited = row[historyColumns.paramsEdited];
     // newrow[bookmarkColumns.paramsEdited] = paramsEdited;
 
-    bTreeView->set_cursor(Gtk::TreeModel::Path(newit), *bTreeView->get_column(0), true);
+    bTreeView->set_cursor(Gtk::TreeModel::Path(newit),
+                          *bTreeView->get_column(0), true);
 }
 
-void History::addBookmarkPressed ()
+void History::addBookmarkPressed()
 {
 
     if (hTreeView->get_selection()->get_selected()) {
@@ -385,7 +401,8 @@ void History::addBookmarkPressed ()
             names.insert(p.first);
         }
         do {
-            name = Glib::ustring::compose("%1 %2", M("HISTORY_SNAPSHOT"), bmnum++);
+            name =
+                Glib::ustring::compose("%1 %2", M("HISTORY_SNAPSHOT"), bmnum++);
         } while (names.find(name) != names.end());
         addBookmarkWithText(name);
 
@@ -395,7 +412,7 @@ void History::addBookmarkPressed ()
     }
 }
 
-void History::delBookmarkPressed ()
+void History::delBookmarkPressed()
 {
 
     // lookup the selected item in the bookmark
@@ -407,35 +424,35 @@ void History::delBookmarkPressed ()
     }
 
     // remove selected bookmark
-    bookmarkModel->erase (iter);
+    bookmarkModel->erase(iter);
     // select last item in history
-    int size = historyModel->children().size ();
+    int size = historyModel->children().size();
     Gtk::TreeModel::Row row = historyModel->children()[size - 1];
-    hTreeView->get_selection()->select (row);
+    hTreeView->get_selection()->select(row);
 
     if (snapshotListener) {
         snapshotListener->snapshotsChanged(getSnapshots());
     }
 }
 
-void History::undo ()
+void History::undo()
 {
 
     Glib::RefPtr<Gtk::TreeSelection> selection = hTreeView->get_selection();
     Gtk::TreeModel::iterator iter = selection->get_selected();
 
     if (iter && iter != historyModel->children().begin()) {
-        selection->select (--iter);
+        selection->select(--iter);
     } else if (!iter) {
-        int size = historyModel->children().size ();
+        int size = historyModel->children().size();
 
         if (size > 1) {
-            selection->select (historyModel->children().operator [](size - 2));
+            selection->select(historyModel->children().operator[](size - 2));
         }
     }
 }
 
-void History::redo ()
+void History::redo()
 {
 
     Glib::RefPtr<Gtk::TreeSelection> selection = hTreeView->get_selection();
@@ -445,13 +462,13 @@ void History::redo ()
         ++iter;
 
         if (iter != historyModel->children().end()) {
-            selection->select (iter);
+            selection->select(iter);
         }
     } else {
-        int size = historyModel->children().size ();
+        int size = historyModel->children().size();
 
         if (size > 1) {
-            selection->select (historyModel->children().operator [](size - 2));
+            selection->select(historyModel->children().operator[](size - 2));
         }
     }
 }
@@ -462,22 +479,24 @@ void History::resized (Gtk::Allocation& req)
 }
 */
 
-bool History::getBeforeAfterParams(rtengine::procparams::ProcParams& params)
+bool History::getBeforeAfterParams(rtengine::procparams::ProcParams &params)
 {
 
-    int size = historyModel->children().size ();
+    int size = historyModel->children().size();
 
     if (size == 0 || !blistener) {
         return false;
     }
 
     Gtk::TreeModel::Row row;
-    row = historyModel->children()[size - 1];//size == 1 ? 0 : size - 2];
+    row = historyModel->children()[size - 1]; // size == 1 ? 0 : size - 2];
     params = row[historyColumns.params];
     return true;
 }
 
-bool History::on_query_tooltip(int x, int y, bool keyboard_tooltip, const Glib::RefPtr<Gtk::Tooltip>& tooltip) {
+bool History::on_query_tooltip(int x, int y, bool keyboard_tooltip,
+                               const Glib::RefPtr<Gtk::Tooltip> &tooltip)
+{
     bool displayTooltip = false;
 
     Gtk::TreeModel::Path path;
@@ -519,14 +538,14 @@ bool History::on_query_tooltip(int x, int y, bool keyboard_tooltip, const Glib::
     return displayTooltip;
 }
 
-
 void History::setPParamsSnapshotListener(PParamsSnapshotListener *l)
 {
     snapshotListener = l;
 }
 
-
-void History::setSnapshots(const std::vector<std::pair<Glib::ustring, rtengine::procparams::ProcParams>> &snapshots)
+void History::setSnapshots(
+    const std::vector<
+        std::pair<Glib::ustring, rtengine::procparams::ProcParams>> &snapshots)
 {
     bookmarkModel->clear();
     for (auto &p : snapshots) {
@@ -537,30 +556,26 @@ void History::setSnapshots(const std::vector<std::pair<Glib::ustring, rtengine::
     }
 }
 
-
-std::vector<std::pair<Glib::ustring, rtengine::procparams::ProcParams>> History::getSnapshots()
+std::vector<std::pair<Glib::ustring, rtengine::procparams::ProcParams>>
+History::getSnapshots()
 {
     std::vector<std::pair<Glib::ustring, rtengine::procparams::ProcParams>> ret;
     for (const auto &row : bookmarkModel->children()) {
-        ret.push_back(std::make_pair(row[bookmarkColumns.text], row[bookmarkColumns.params]));
+        ret.push_back(std::make_pair(row[bookmarkColumns.text],
+                                     row[bookmarkColumns.params]));
     }
     return ret;
 }
 
-
-void History::snapshotNameEdited(const Glib::ustring &sold, const Glib::ustring &snew)
+void History::snapshotNameEdited(const Glib::ustring &sold,
+                                 const Glib::ustring &snew)
 {
     if (snapshotListener) {
         snapshotListener->snapshotsChanged(getSnapshots());
     }
 }
 
-
-void History::enableSnapshots(bool yes)
-{
-    bTreeView->set_sensitive(yes);
-}
-
+void History::enableSnapshots(bool yes) { bTreeView->set_sensitive(yes); }
 
 bool History::onPressEvent(GdkEventButton *event)
 {
@@ -573,7 +588,6 @@ bool History::onPressEvent(GdkEventButton *event)
     return false;
 }
 
-
 bool History::confirmBookmarkUpdate()
 {
     Gtk::Popover p(*bTreeView);
@@ -593,14 +607,23 @@ bool History::confirmBookmarkUpdate()
 
     int result = 0;
 
-    ok.signal_clicked().connect(sigc::slot<void>([&](){ result = 1; p.hide(); }));
-    cancel.signal_clicked().connect(sigc::slot<void>([&](){ result = -1; p.hide(); }));
-    p.signal_closed().connect(sigc::slot<void>([&](){ if (!result) result = -1; }));
+    ok.signal_clicked().connect(sigc::slot<void>([&]() {
+        result = 1;
+        p.hide();
+    }));
+    cancel.signal_clicked().connect(sigc::slot<void>([&]() {
+        result = -1;
+        p.hide();
+    }));
+    p.signal_closed().connect(sigc::slot<void>([&]() {
+        if (!result)
+            result = -1;
+    }));
 
     p.show_all_children();
     p.set_modal(true);
     p.show();
-    //p.popup();
+    // p.popup();
 
     while (result == 0) {
         gtk_main_iteration();
@@ -609,7 +632,6 @@ bool History::confirmBookmarkUpdate()
     return result == 1;
 }
 
-
 void History::setBeforeAfterLock(bool yes)
 {
     blistenerLock = yes;
@@ -617,19 +639,19 @@ void History::setBeforeAfterLock(bool yes)
         Glib::RefPtr<Gtk::TreeSelection> selection = hTreeView->get_selection();
         Gtk::TreeModel::iterator iter = selection->get_selected();
         if (iter) {
-            blistener->historyBeforeAfterChanged(iter->get_value(historyColumns.params));
+            blistener->historyBeforeAfterChanged(
+                iter->get_value(historyColumns.params));
         }
     }
 }
 
-
 void History::activateNextSnapshot()
 {
     auto children = bookmarkModel->children();
     if (children.size() == 0) {
         return;
     }
-    
+
     Glib::RefPtr<Gtk::TreeSelection> selection = bTreeView->get_selection();
     Gtk::TreeModel::iterator iter = selection->get_selected();
 
@@ -645,14 +667,13 @@ void History::activateNextSnapshot()
     }
 }
 
-
 void History::activatePrevSnapshot()
 {
     auto children = bookmarkModel->children();
     if (children.size() == 0) {
         return;
     }
-    
+
     Glib::RefPtr<Gtk::TreeSelection> selection = bTreeView->get_selection();
     Gtk::TreeModel::iterator iter = selection->get_selected();
 
