@@ -1,5 +1,5 @@
 /* -*- C++ -*-
- *  
+ *
  *  This file is part of RawTherapee.
  *
  *  Copyright (c) 2018 Jean-Christophe FRISCH <natureh.510@gmail.com>
@@ -23,39 +23,42 @@
 #include <gtkmm/image.h>
 
 /**
- * @brief A master class for derived class of Gtk::Image in order to handle theme-related icon sets.
+ * @brief A master class for derived class of Gtk::Image in order to handle
+ * theme-related icon sets.
  */
 class RTScalable {
     static double dpi;
     static int scale;
     static int device_scale;
-    static Gtk::TextDirection direction;  // cached value for text-direction
-    static void deleteDir(const Glib::ustring& path);
+    static Gtk::TextDirection direction; // cached value for text-direction
+    static void deleteDir(const Glib::ustring &path);
 
 protected:
-    static void setDPInScale (const double newDPI, const int newScale);
-    static Cairo::RefPtr<Cairo::ImageSurface> loadImage(const Glib::ustring &fname, double dpi);
+    static void setDPInScale(const double newDPI, const int newScale);
+    static Cairo::RefPtr<Cairo::ImageSurface>
+    loadImage(const Glib::ustring &fname, double dpi);
     static Gtk::TextDirection getDirection();
 
-
 public:
-
 #ifdef __APPLE__
     static constexpr double baseDPI = 72.;
     static constexpr double baseHiDPI = 144.;
-    static constexpr int    baseFontSize = 12;
+    static constexpr int baseFontSize = 12;
 #else
     static constexpr double baseDPI = 96.;
     static constexpr double baseHiDPI = 192.;
-    static constexpr int    baseFontSize = 9;
+    static constexpr int baseFontSize = 9;
 #endif
 
     static void init(Gtk::Window *window);
     static void cleanup(bool all = false);
-    static double getDPI ();
-    static double getTweakedDPI ();   // The returned value is tweaked DPI to adapt to main the font size. Maybe not an ideal solution.
-    static int getScale ();
+    static double getDPI();
+    static double
+    getTweakedDPI(); // The returned value is tweaked DPI to adapt to main the
+                     // font size. Maybe not an ideal solution.
+    static int getScale();
     static int getDeviceScale();
 
-    static void setDeviceScale(const Cairo::RefPtr<Cairo::Surface>& surface, int scale);
+    static void setDeviceScale(const Cairo::RefPtr<Cairo::Surface> &surface,
+                               int scale);
 };
